import pytest
import os

import numpy as np

base_files_path = os.path.join("examples", "molecule_files", "json_files")


class BaseTestJSONParser:
    acetone_2d = os.path.join(base_files_path, "acetone_2d.json")
    acetone_3d = os.path.join(base_files_path, "acetone_3d.json")
    morphine_2d = os.path.join(base_files_path, "morphine_2d.json")
    morphine_3d = os.path.join(base_files_path, "morphine_3d.json")
    heme_2d = os.path.join(base_files_path, "heme_2d.json")
    heme_3d = os.path.join(base_files_path, "heme_3d.json")

    @pytest.fixture
    def acetone_2d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 180}},
                    "atoms": {
                        "aid": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
                        "element": [8, 6, 6, 6, 1, 1, 1, 1, 1, 1],
                    },
                    "bonds": {
                        "aid1": [1, 2, 2, 3, 3, 3, 4, 4, 4],
                        "aid2": [2, 3, 4, 5, 6, 7, 8, 9, 10],
                        "order": [2, 1, 1, 1, 1, 1, 1, 1, 1],
                    },
                    "coords": [
                        {
                            "type": [1, 5, 255],
                            "aid": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
                            "conformers": [
                                {
                                    "x": [
                                        3.732,
                                        2.866,
                                        2,
                                        2.866,
                                        2.31,
                                        1.4631,
                                        1.69,
                                        2.246,
                                        2.866,
                                        3.486,
                                    ],
                                    "y": [
                                        0.75,
                                        0.25,
                                        0.75,
                                        -0.75,
                                        1.2869,
                                        1.06,
                                        0.2131,
                                        -0.75,
                                        -1.37,
                                        -0.75,
                                    ],
                                }
                            ],
                        }
                    ],
                    "charge": 0,
                    "props": [
                        {
                            "urn": {
                                "label": "Compound",
                                "name": "Canonicalized",
                                "datatype": 5,
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 1},
                        },
                        {
                            "urn": {
                                "label": "Compound Complexity",
                                "datatype": 7,
                                "implementation": "E_COMPLEXITY",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 26.3},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Acceptor",
                                "datatype": 5,
                                "implementation": "E_NHACCEPTORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 1},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Donor",
                                "datatype": 5,
                                "implementation": "E_NHDONORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 0},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Rotatable Bond",
                                "datatype": 5,
                                "implementation": "E_NROTBONDS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 0},
                        },
                        {
                            "urn": {
                                "label": "Fingerprint",
                                "name": "SubStructure Keys",
                                "datatype": 16,
                                "parameters": "extended 2",
                                "implementation": "E_SCREEN",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "binary": "0000037180402000000000000000000000000000000000000000000000000000000000000000001A000000000008048080000200000000000800801000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Allowed",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "acetone"},
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "CAS-like Style",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "2-propanone"},
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Markup",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "propan-2-one"},
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Preferred",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "propan-2-one"},
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Systematic",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "propan-2-one"},
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Traditional",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "acetone"},
                        },
                        {
                            "urn": {
                                "label": "InChI",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "InChI=1S/C3H6O/c1-3(2)4/h1-2H3"},
                        },
                        {
                            "urn": {
                                "label": "InChIKey",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "CSCPPACGZOOCGX-UHFFFAOYSA-N"},
                        },
                        {
                            "urn": {
                                "label": "Log P",
                                "name": "XLogP3-AA",
                                "datatype": 7,
                                "version": "3.0",
                                "source": "sioc-ccbg.ac.cn",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": -0.1},
                        },
                        {
                            "urn": {
                                "label": "Mass",
                                "name": "Exact",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "58.041864811"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Formula",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "C3H6O"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Weight",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "58.08"},
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Absolute",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2024.12.12",
                            },
                            "value": {"sval": "CC(=O)C"},
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Canonical",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "CC(=O)C"},
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Isomeric",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "CC(=O)C"},
                        },
                        {
                            "urn": {
                                "label": "Topological",
                                "name": "Polar Surface Area",
                                "datatype": 7,
                                "implementation": "E_TPSA",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 17.1},
                        },
                        {
                            "urn": {
                                "label": "Weight",
                                "name": "MonoIsotopic",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "58.041864811"},
                        },
                    ],
                    "count": {
                        "heavy_atom": 4,
                        "atom_chiral": 0,
                        "atom_chiral_def": 0,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 1,
                        "tautomers": -1,
                    },
                }
            ]
        }

    @pytest.fixture
    def acetone_3d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 180}},
                    "atoms": {
                        "aid": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
                        "element": [8, 6, 6, 6, 1, 1, 1, 1, 1, 1],
                    },
                    "bonds": {
                        "aid1": [1, 2, 2, 3, 3, 3, 4, 4, 4],
                        "aid2": [2, 3, 4, 5, 6, 7, 8, 9, 10],
                        "order": [2, 1, 1, 1, 1, 1, 1, 1, 1],
                    },
                    "coords": [
                        {
                            "type": [2, 5, 10],
                            "aid": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
                            "conformers": [
                                {
                                    "x": [
                                        0.0003,
                                        0,
                                        1.281,
                                        -1.2813,
                                        1.3279,
                                        1.326,
                                        2.1351,
                                        -2.1352,
                                        -1.3284,
                                        -1.3266,
                                    ],
                                    "y": [
                                        -1.3171,
                                        -0.0872,
                                        0.7024,
                                        0.7019,
                                        1.3235,
                                        1.3282,
                                        0.0196,
                                        0.0187,
                                        1.323,
                                        1.3278,
                                    ],
                                    "z": [
                                        -0.0002,
                                        0.0006,
                                        -0.0002,
                                        -0.0002,
                                        -0.898,
                                        0.8945,
                                        0.0027,
                                        0.0027,
                                        -0.898,
                                        0.8945,
                                    ],
                                    "data": [
                                        {
                                            "urn": {
                                                "label": "Conformer",
                                                "name": "ID",
                                                "datatype": 11,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2009.12.11",
                                            },
                                            "value": {"sval": "000000B400000001"},
                                        },
                                        {
                                            "urn": {
                                                "label": "Energy",
                                                "name": "MMFF94 NoEstat",
                                                "datatype": 7,
                                                "version": "1.6.0",
                                                "software": "Szybki",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 1.6523},
                                        },
                                        {
                                            "urn": {
                                                "label": "Feature",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 5.074},
                                        },
                                        {
                                            "urn": {
                                                "label": "Fingerprint",
                                                "name": "Shape",
                                                "datatype": 2,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.11.26",
                                            },
                                            "value": {
                                                "slist": [
                                                    "139733 1 9290717673991302211",
                                                    "20096714 4 18411138026090193976",
                                                    "21015797 1 9007056889502236007",
                                                    "5943 1 13610069792663804549",
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Multipoles",
                                                "datatype": 8,
                                                "version": "1.8.1",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {
                                                "fvec": [
                                                    76.45,
                                                    1.48,
                                                    1.18,
                                                    0.59,
                                                    0,
                                                    0.33,
                                                    0,
                                                    -0.56,
                                                    0,
                                                    0,
                                                    0,
                                                    0,
                                                    -0.03,
                                                    0,
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 128.735},
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Volume",
                                                "datatype": 7,
                                                "version": "1.8.1",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 52.8},
                                        },
                                    ],
                                }
                            ],
                            "data": [
                                {
                                    "urn": {
                                        "label": "Conformer",
                                        "name": "RMSD",
                                        "datatype": 7,
                                        "release": "2009.12.11",
                                    },
                                    "value": {"fval": 0.4},
                                },
                                {
                                    "urn": {
                                        "label": "Diverse Conformer",
                                        "name": "ID List",
                                        "datatype": 6,
                                        "release": "2010.05.05",
                                    },
                                    "value": {"ivec": [1]},
                                },
                            ],
                        }
                    ],
                    "props": [
                        {
                            "urn": {
                                "label": "Charge",
                                "name": "MMFF94 Partial",
                                "datatype": 2,
                                "version": "1.9.0",
                                "software": "OEChem",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {
                                "slist": ["4", "1 -0.57", "2 0.45", "3 0.06", "4 0.06"]
                            },
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Effective Rotor",
                                "datatype": 7,
                                "version": "1.7.6",
                                "software": "OEChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2012.01.18",
                            },
                            "value": {"fval": 0},
                        },
                        {
                            "urn": {
                                "label": "Features",
                                "name": "Pharmacophore",
                                "datatype": 2,
                                "parameters": "ImplicitMillsDean merged",
                                "version": "1.8.3",
                                "software": "OEShape",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {"slist": ["1", "1 1 acceptor"]},
                        },
                    ],
                    "count": {
                        "heavy_atom": 4,
                        "atom_chiral": 0,
                        "atom_chiral_def": 0,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 1,
                        "tautomers": 2,
                    },
                }
            ]
        }

    @pytest.fixture
    def morphine_2d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 5288826}},
                    "atoms": {
                        "aid": [
                            1,
                            2,
                            3,
                            4,
                            5,
                            6,
                            7,
                            8,
                            9,
                            10,
                            11,
                            12,
                            13,
                            14,
                            15,
                            16,
                            17,
                            18,
                            19,
                            20,
                            21,
                            22,
                            23,
                            24,
                            25,
                            26,
                            27,
                            28,
                            29,
                            30,
                            31,
                            32,
                            33,
                            34,
                            35,
                            36,
                            37,
                            38,
                            39,
                            40,
                        ],
                        "element": [
                            8,
                            8,
                            8,
                            7,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                    },
                    "bonds": {
                        "aid1": [
                            1,
                            1,
                            2,
                            2,
                            3,
                            3,
                            4,
                            4,
                            4,
                            5,
                            5,
                            5,
                            5,
                            6,
                            6,
                            6,
                            7,
                            7,
                            8,
                            8,
                            9,
                            9,
                            9,
                            10,
                            10,
                            11,
                            11,
                            11,
                            12,
                            12,
                            13,
                            14,
                            14,
                            15,
                            15,
                            16,
                            17,
                            18,
                            18,
                            18,
                            19,
                            19,
                            20,
                            21,
                        ],
                        "aid2": [
                            8,
                            16,
                            14,
                            39,
                            20,
                            40,
                            7,
                            12,
                            18,
                            6,
                            8,
                            9,
                            10,
                            7,
                            15,
                            22,
                            11,
                            23,
                            14,
                            24,
                            12,
                            25,
                            26,
                            13,
                            16,
                            13,
                            27,
                            28,
                            29,
                            30,
                            19,
                            17,
                            31,
                            17,
                            32,
                            20,
                            33,
                            34,
                            35,
                            36,
                            21,
                            37,
                            21,
                            38,
                        ],
                        "order": [
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                        ],
                    },
                    "stereo": [
                        {
                            "tetrahedral": {
                                "center": 5,
                                "above": 6,
                                "top": 8,
                                "bottom": 9,
                                "below": 10,
                                "parity": 1,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 6,
                                "above": 5,
                                "top": 15,
                                "bottom": 7,
                                "below": 22,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 7,
                                "above": 4,
                                "top": 6,
                                "bottom": 11,
                                "below": 23,
                                "parity": 1,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 8,
                                "above": 1,
                                "top": 14,
                                "bottom": 5,
                                "below": 24,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 14,
                                "above": 2,
                                "top": 17,
                                "bottom": 8,
                                "below": 31,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                    ],
                    "coords": [
                        {
                            "type": [1, 5, 255],
                            "aid": [
                                1,
                                2,
                                3,
                                4,
                                5,
                                6,
                                7,
                                8,
                                9,
                                10,
                                11,
                                12,
                                13,
                                14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31,
                                32,
                                33,
                                34,
                                35,
                                36,
                                37,
                                38,
                                39,
                                40,
                            ],
                            "conformers": [
                                {
                                    "x": [
                                        2.2314,
                                        2,
                                        2,
                                        6.1607,
                                        3.6897,
                                        4.5133,
                                        5.337,
                                        2.866,
                                        4.2392,
                                        3.6897,
                                        5.337,
                                        5.5918,
                                        4.5133,
                                        2.866,
                                        4.5133,
                                        2.866,
                                        3.6897,
                                        6.8418,
                                        4.5133,
                                        2.866,
                                        3.6897,
                                        5.0597,
                                        5.6284,
                                        2.0496,
                                        4.376,
                                        3.6795,
                                        5.9476,
                                        5.549,
                                        6.184,
                                        5.4989,
                                        2.866,
                                        5.0503,
                                        3.6897,
                                        6.3879,
                                        7.2641,
                                        7.2957,
                                        5.0503,
                                        3.6897,
                                        2,
                                        2,
                                    ],
                                    "y": [
                                        0.0528,
                                        -2.4021,
                                        2.4021,
                                        -0.9511,
                                        -0.4755,
                                        -0.9511,
                                        -0.4755,
                                        -0.9511,
                                        0.2219,
                                        0.4755,
                                        0.4755,
                                        0.2219,
                                        0.9511,
                                        -1.9022,
                                        -1.9022,
                                        0.9511,
                                        -2.3777,
                                        -1.6832,
                                        1.9022,
                                        1.9022,
                                        2.3777,
                                        -1.6022,
                                        -1.274,
                                        -1.1875,
                                        0.8266,
                                        0.4887,
                                        0.3679,
                                        1.0581,
                                        0.4057,
                                        0.8349,
                                        -2.5222,
                                        -2.2122,
                                        -2.9977,
                                        -2.1055,
                                        -2.1371,
                                        -1.2609,
                                        2.2122,
                                        2.9977,
                                        -3.0222,
                                        3.0222,
                                    ],
                                    "style": {
                                        "annotation": [5, 5, 6, 5, 8, 8, 8, 6, 8, 8, 8],
                                        "aid1": [
                                            5,
                                            6,
                                            7,
                                            8,
                                            10,
                                            10,
                                            13,
                                            14,
                                            16,
                                            19,
                                            20,
                                        ],
                                        "aid2": [
                                            9,
                                            22,
                                            23,
                                            24,
                                            13,
                                            16,
                                            19,
                                            2,
                                            20,
                                            21,
                                            21,
                                        ],
                                    },
                                }
                            ],
                        }
                    ],
                    "charge": 0,
                    "props": [
                        {
                            "urn": {
                                "label": "Compound",
                                "name": "Canonicalized",
                                "datatype": 5,
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 1},
                        },
                        {
                            "urn": {
                                "label": "Compound Complexity",
                                "datatype": 7,
                                "implementation": "E_COMPLEXITY",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 494},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Acceptor",
                                "datatype": 5,
                                "implementation": "E_NHACCEPTORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 4},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Donor",
                                "datatype": 5,
                                "implementation": "E_NHDONORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 2},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Rotatable Bond",
                                "datatype": 5,
                                "implementation": "E_NROTBONDS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 0},
                        },
                        {
                            "urn": {
                                "label": "Fingerprint",
                                "name": "SubStructure Keys",
                                "datatype": 16,
                                "parameters": "extended 2",
                                "implementation": "E_SCREEN",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "binary": "00000371E07A30000000000000000000000000000001200000003C6081000000160048C10000001E00000800000F3CE198063206830006008002204200000208002020000888000E88880D362286B11B867823A4C0118BB807B0F0F70FA000010000184000D000068000348000000000000000"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Allowed",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4R,4aR,7S,7aR,12bS)-3-methyl-2,4,4a,7,7a,13-hexahydro-1H-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "CAS-like Style",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4R,4aR,7S,7aR,12bS)-3-methyl-2,4,4a,7,7a,13-hexahydro-1H-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Markup",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4<I>R</I>,4<I>a</I><I>R</I>,7<I>S</I>,7<I>a</I><I>R</I>,12<I>b</I><I>S</I>)-3-methyl-2,4,4<I>a</I>,7,7<I>a</I>,13-hexahydro-1<I>H</I>-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Preferred",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4R,4aR,7S,7aR,12bS)-3-methyl-2,4,4a,7,7a,13-hexahydro-1H-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Systematic",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4R,4aR,7S,7aR,12bS)-3-methyl-2,4,4a,7,7a,13-hexahydro-1H-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Traditional",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "(4R,4aR,7S,7aR,12bS)-3-methyl-2,4,4a,7,7a,13-hexahydro-1H-4,12-methanobenzofuro[3,2-e]isoquinoline-7,9-diol"
                            },
                        },
                        {
                            "urn": {
                                "label": "InChI",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "InChI=1S/C17H19NO3/c1-18-7-6-17-10-3-5-13(20)16(17)21-15-12(19)4-2-9(14(15)17)8-11(10)18/h2-5,10-11,13,16,19-20H,6-8H2,1H3/t10-,11+,13-,16-,17-/m0/s1"
                            },
                        },
                        {
                            "urn": {
                                "label": "InChIKey",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "BQJCRHHNABKAKU-KBQPJGBKSA-N"},
                        },
                        {
                            "urn": {
                                "label": "Log P",
                                "name": "XLogP3",
                                "datatype": 7,
                                "version": "3.0",
                                "source": "sioc-ccbg.ac.cn",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 0.8},
                        },
                        {
                            "urn": {
                                "label": "Mass",
                                "name": "Exact",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "285.13649347"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Formula",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "C17H19NO3"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Weight",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "285.34"},
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Absolute",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2024.12.12",
                            },
                            "value": {
                                "sval": "CN1CC[C@]23[C@@H]4[C@H]1CC5=C2C(=C(C=C5)O)O[C@H]3[C@H](C=C4)O"
                            },
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Canonical",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "CN1CCC23C4C1CC5=C2C(=C(C=C5)O)OC3C(C=C4)O"
                            },
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Isomeric",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "CN1CC[C@]23[C@@H]4[C@H]1CC5=C2C(=C(C=C5)O)O[C@H]3[C@H](C=C4)O"
                            },
                        },
                        {
                            "urn": {
                                "label": "Topological",
                                "name": "Polar Surface Area",
                                "datatype": 7,
                                "implementation": "E_TPSA",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 52.9},
                        },
                        {
                            "urn": {
                                "label": "Weight",
                                "name": "MonoIsotopic",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "285.13649347"},
                        },
                    ],
                    "count": {
                        "heavy_atom": 21,
                        "atom_chiral": 5,
                        "atom_chiral_def": 5,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 1,
                        "tautomers": -1,
                    },
                }
            ]
        }

    @pytest.fixture
    def morphine_3d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 5288826}},
                    "atoms": {
                        "aid": [
                            1,
                            2,
                            3,
                            4,
                            5,
                            6,
                            7,
                            8,
                            9,
                            10,
                            11,
                            12,
                            13,
                            14,
                            15,
                            16,
                            17,
                            18,
                            19,
                            20,
                            21,
                            22,
                            23,
                            24,
                            25,
                            26,
                            27,
                            28,
                            29,
                            30,
                            31,
                            32,
                            33,
                            34,
                            35,
                            36,
                            37,
                            38,
                            39,
                            40,
                        ],
                        "element": [
                            8,
                            8,
                            8,
                            7,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                    },
                    "bonds": {
                        "aid1": [
                            1,
                            1,
                            2,
                            2,
                            3,
                            3,
                            4,
                            4,
                            4,
                            5,
                            5,
                            5,
                            5,
                            6,
                            6,
                            6,
                            7,
                            7,
                            8,
                            8,
                            9,
                            9,
                            9,
                            10,
                            10,
                            11,
                            11,
                            11,
                            12,
                            12,
                            13,
                            14,
                            14,
                            15,
                            15,
                            16,
                            17,
                            18,
                            18,
                            18,
                            19,
                            19,
                            20,
                            21,
                        ],
                        "aid2": [
                            8,
                            16,
                            14,
                            39,
                            20,
                            40,
                            7,
                            12,
                            18,
                            6,
                            8,
                            9,
                            10,
                            7,
                            15,
                            22,
                            11,
                            23,
                            14,
                            24,
                            12,
                            25,
                            26,
                            13,
                            16,
                            13,
                            27,
                            28,
                            29,
                            30,
                            19,
                            17,
                            31,
                            17,
                            32,
                            20,
                            33,
                            34,
                            35,
                            36,
                            21,
                            37,
                            21,
                            38,
                        ],
                        "order": [
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                        ],
                    },
                    "stereo": [
                        {
                            "tetrahedral": {
                                "center": 5,
                                "above": 6,
                                "top": 8,
                                "bottom": 9,
                                "below": 10,
                                "parity": 1,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 6,
                                "above": 5,
                                "top": 15,
                                "bottom": 7,
                                "below": 22,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 7,
                                "above": 4,
                                "top": 6,
                                "bottom": 11,
                                "below": 23,
                                "parity": 1,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 8,
                                "above": 1,
                                "top": 14,
                                "bottom": 5,
                                "below": 24,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                        {
                            "tetrahedral": {
                                "center": 14,
                                "above": 2,
                                "top": 17,
                                "bottom": 8,
                                "below": 31,
                                "parity": 2,
                                "type": 1,
                            }
                        },
                    ],
                    "coords": [
                        {
                            "type": [2, 5, 10],
                            "aid": [
                                1,
                                2,
                                3,
                                4,
                                5,
                                6,
                                7,
                                8,
                                9,
                                10,
                                11,
                                12,
                                13,
                                14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31,
                                32,
                                33,
                                34,
                                35,
                                36,
                                37,
                                38,
                                39,
                                40,
                            ],
                            "conformers": [
                                {
                                    "x": [
                                        -1.993,
                                        -2.7826,
                                        -3.622,
                                        3.1777,
                                        0.3699,
                                        1.2913,
                                        2.3441,
                                        -0.9377,
                                        1.1988,
                                        -0.2516,
                                        1.6887,
                                        2.4315,
                                        0.3384,
                                        -1.3631,
                                        0.5066,
                                        -1.5672,
                                        -0.7155,
                                        4.3733,
                                        -0.4184,
                                        -2.331,
                                        -1.7382,
                                        1.8278,
                                        3.0029,
                                        -0.8451,
                                        1.5366,
                                        0.5899,
                                        1.5474,
                                        2.353,
                                        2.1271,
                                        3.0801,
                                        -1.0772,
                                        0.9601,
                                        -1.23,
                                        4.15,
                                        4.938,
                                        5.0444,
                                        -0.0062,
                                        -2.3121,
                                        -3.1557,
                                        -3.8483,
                                    ],
                                    "y": [
                                        -0.474,
                                        -2.5168,
                                        1.8421,
                                        -0.0101,
                                        -0.7149,
                                        -1.3046,
                                        -0.2023,
                                        -1.475,
                                        -0.3907,
                                        0.5302,
                                        1.1052,
                                        0.4754,
                                        1.4306,
                                        -2.5067,
                                        -1.8183,
                                        0.6306,
                                        -2.3492,
                                        0.7916,
                                        2.5415,
                                        1.7217,
                                        2.6936,
                                        -2.1759,
                                        -0.6035,
                                        -2.0128,
                                        -1.3335,
                                        0.1174,
                                        0.9596,
                                        1.968,
                                        1.5205,
                                        0.4584,
                                        -3.5067,
                                        -1.7947,
                                        -2.7505,
                                        1.8479,
                                        0.4055,
                                        0.7352,
                                        3.2824,
                                        3.5638,
                                        -2.6446,
                                        1.0686,
                                    ],
                                    "z": [
                                        1.2005,
                                        -0.2218,
                                        0.5579,
                                        0.4474,
                                        0.6616,
                                        -0.417,
                                        -0.764,
                                        0.9848,
                                        1.9201,
                                        0.1205,
                                        -1.3279,
                                        1.6126,
                                        -0.748,
                                        -0.0924,
                                        -1.5971,
                                        0.5136,
                                        -1.4425,
                                        0.2084,
                                        -1.1246,
                                        0.162,
                                        -0.6541,
                                        -0.0118,
                                        -1.5465,
                                        1.9373,
                                        2.3712,
                                        2.679,
                                        -2.4075,
                                        -1.2194,
                                        1.476,
                                        2.4975,
                                        0.2593,
                                        -2.5831,
                                        -2.3109,
                                        0.0287,
                                        -0.6472,
                                        1.073,
                                        -1.8043,
                                        -0.9645,
                                        0.6672,
                                        1.1031,
                                    ],
                                    "data": [
                                        {
                                            "urn": {
                                                "label": "Conformer",
                                                "name": "ID",
                                                "datatype": 11,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2009.12.11",
                                            },
                                            "value": {"sval": "0050B37A00000001"},
                                        },
                                        {
                                            "urn": {
                                                "label": "Energy",
                                                "name": "MMFF94 NoEstat",
                                                "datatype": 7,
                                                "version": "1.6.0",
                                                "software": "Szybki",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 74.8429},
                                        },
                                        {
                                            "urn": {
                                                "label": "Feature",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 52.873},
                                        },
                                        {
                                            "urn": {
                                                "label": "Fingerprint",
                                                "name": "Shape",
                                                "datatype": 2,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.11.26",
                                            },
                                            "value": {
                                                "slist": [
                                                    "10165383 225 18201451224619826784",
                                                    "10863032 1 18271807882738128182",
                                                    "10871710 139 17975427020448559044",
                                                    "10948715 1 18269553840856601268",
                                                    "11578080 2 17916862543033451120",
                                                    "12035758 1 17979921506076134602",
                                                    "12326174 3 16761939621672351259",
                                                    "12403814 3 18127127700562790162",
                                                    "12423570 1 13554306196661771698",
                                                    "13132413 78 16832327581639147097",
                                                    "13140716 1 18188786057421996321",
                                                    "13172582 1 18260836951273720209",
                                                    "13681431 1 17258466355483259718",
                                                    "141345 1 11468367428490074574",
                                                    "144361 1 17623048910753830566",
                                                    "14817 1 13651070280742688743",
                                                    "15852999 172 18199182901892535827",
                                                    "16945 1 18189637062236146638",
                                                    "17357779 13 17772166846782183447",
                                                    "18393751 57 17187542376137546200",
                                                    "19868273 325 18263924500288743760",
                                                    "21524375 3 18267574711299526024",
                                                    "22112679 90 18121790679236681172",
                                                    "22182313 1 18194427527483256583",
                                                    "2334 1 17972616638225251261",
                                                    "23388829 49 17833828657105785732",
                                                    "23402539 116 18338509850163596911",
                                                    "23419403 2 15694871661581035675",
                                                    "23557571 272 18270408299151999272",
                                                    "23559900 14 18059580127798590934",
                                                    "238 59 17618764874292193101",
                                                    "2748010 2 17975155161707925181",
                                                    "34934 24 18113338621838265964",
                                                    "495365 180 17547829890269334821",
                                                    "7364860 26 17256519721717681045",
                                                    "81228 2 18194937829152466419",
                                                    "84936 31 17124492616027647943",
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Multipoles",
                                                "datatype": 8,
                                                "version": "1.8.1",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {
                                                "fvec": [
                                                    409.58,
                                                    4.45,
                                                    3.02,
                                                    1.55,
                                                    2.3,
                                                    0.24,
                                                    -0.13,
                                                    -1.6,
                                                    -0.99,
                                                    -2.59,
                                                    1.17,
                                                    0.46,
                                                    0.26,
                                                    -0.03,
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 930.437},
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Volume",
                                                "datatype": 7,
                                                "version": "1.8.1",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.01.18",
                                            },
                                            "value": {"fval": 211.2},
                                        },
                                    ],
                                }
                            ],
                            "data": [
                                {
                                    "urn": {
                                        "label": "Conformer",
                                        "name": "RMSD",
                                        "datatype": 7,
                                        "release": "2009.12.11",
                                    },
                                    "value": {"fval": 0.6},
                                },
                                {
                                    "urn": {
                                        "label": "Diverse Conformer",
                                        "name": "ID List",
                                        "datatype": 6,
                                        "release": "2010.05.05",
                                    },
                                    "value": {"ivec": [1]},
                                },
                            ],
                        }
                    ],
                    "props": [
                        {
                            "urn": {
                                "label": "Charge",
                                "name": "MMFF94 Partial",
                                "datatype": 2,
                                "version": "1.9.0",
                                "software": "OEChem",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {
                                "slist": [
                                    "26",
                                    "1 -0.36",
                                    "10 -0.14",
                                    "11 0.14",
                                    "12 0.27",
                                    "13 -0.14",
                                    "14 0.42",
                                    "15 -0.29",
                                    "16 0.08",
                                    "17 -0.29",
                                    "18 0.27",
                                    "19 -0.15",
                                    "2 -0.68",
                                    "20 0.08",
                                    "21 -0.15",
                                    "3 -0.53",
                                    "32 0.15",
                                    "33 0.15",
                                    "37 0.15",
                                    "38 0.15",
                                    "39 0.4",
                                    "4 -0.81",
                                    "40 0.45",
                                    "5 0.14",
                                    "6 0.14",
                                    "7 0.27",
                                    "8 0.28",
                                ]
                            },
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Effective Rotor",
                                "datatype": 7,
                                "version": "1.7.6",
                                "software": "OEChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2012.01.18",
                            },
                            "value": {"fval": 1.2},
                        },
                        {
                            "urn": {
                                "label": "Features",
                                "name": "Pharmacophore",
                                "datatype": 2,
                                "parameters": "ImplicitMillsDean merged",
                                "version": "1.8.3",
                                "software": "OEShape",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {
                                "slist": [
                                    "10",
                                    "1 1 acceptor",
                                    "1 2 acceptor",
                                    "1 2 donor",
                                    "1 3 donor",
                                    "1 4 cation",
                                    "5 1 5 8 10 16 rings",
                                    "6 10 13 16 19 20 21 rings",
                                    "6 4 5 6 7 9 12 rings",
                                    "6 5 6 7 10 11 13 rings",
                                    "6 5 6 8 14 15 17 rings",
                                ]
                            },
                        },
                    ],
                    "count": {
                        "heavy_atom": 21,
                        "atom_chiral": 5,
                        "atom_chiral_def": 5,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 1,
                        "tautomers": 3,
                    },
                }
            ]
        }

    @pytest.fixture
    def heme_2d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 26945}},
                    "atoms": {
                        "aid": [
                            1,
                            2,
                            3,
                            4,
                            5,
                            6,
                            7,
                            8,
                            9,
                            10,
                            11,
                            12,
                            13,
                            14,
                            15,
                            16,
                            17,
                            18,
                            19,
                            20,
                            21,
                            22,
                            23,
                            24,
                            25,
                            26,
                            27,
                            28,
                            29,
                            30,
                            31,
                            32,
                            33,
                            34,
                            35,
                            36,
                            37,
                            38,
                            39,
                            40,
                            41,
                            42,
                            43,
                            44,
                            45,
                            46,
                            47,
                            48,
                            49,
                            50,
                            51,
                            52,
                            53,
                            54,
                            55,
                            56,
                            57,
                            58,
                            59,
                            60,
                            61,
                            62,
                            63,
                            64,
                            65,
                            66,
                            67,
                            68,
                            69,
                            70,
                            71,
                            72,
                            73,
                            74,
                            75,
                        ],
                        "element": [
                            26,
                            8,
                            8,
                            8,
                            8,
                            7,
                            7,
                            7,
                            7,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                        "charge": [
                            {"aid": 1, "value": 2},
                            {"aid": 6, "value": -1},
                            {"aid": 7, "value": -1},
                        ],
                    },
                    "bonds": {
                        "aid1": [
                            2,
                            2,
                            3,
                            3,
                            4,
                            5,
                            6,
                            6,
                            7,
                            7,
                            8,
                            8,
                            9,
                            9,
                            10,
                            10,
                            10,
                            11,
                            11,
                            11,
                            12,
                            13,
                            14,
                            14,
                            15,
                            15,
                            16,
                            16,
                            16,
                            17,
                            17,
                            17,
                            18,
                            19,
                            20,
                            21,
                            21,
                            22,
                            22,
                            23,
                            23,
                            23,
                            24,
                            24,
                            24,
                            25,
                            26,
                            27,
                            27,
                            27,
                            28,
                            28,
                            28,
                            29,
                            29,
                            30,
                            30,
                            31,
                            31,
                            32,
                            33,
                            33,
                            34,
                            35,
                            36,
                            36,
                            36,
                            37,
                            37,
                            37,
                            40,
                            40,
                            41,
                            41,
                            42,
                            42,
                            43,
                            43,
                        ],
                        "aid2": [
                            38,
                            74,
                            39,
                            75,
                            38,
                            39,
                            12,
                            18,
                            13,
                            19,
                            25,
                            33,
                            26,
                            31,
                            12,
                            14,
                            16,
                            13,
                            15,
                            17,
                            20,
                            20,
                            18,
                            27,
                            19,
                            28,
                            23,
                            44,
                            45,
                            24,
                            46,
                            47,
                            21,
                            22,
                            48,
                            25,
                            49,
                            26,
                            50,
                            38,
                            51,
                            52,
                            39,
                            53,
                            54,
                            29,
                            30,
                            55,
                            56,
                            57,
                            58,
                            59,
                            60,
                            34,
                            36,
                            32,
                            40,
                            32,
                            35,
                            37,
                            34,
                            35,
                            41,
                            61,
                            62,
                            63,
                            64,
                            65,
                            66,
                            67,
                            42,
                            68,
                            43,
                            69,
                            70,
                            71,
                            72,
                            73,
                        ],
                        "order": [
                            1,
                            1,
                            1,
                            1,
                            2,
                            2,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                    },
                    "coords": [
                        {
                            "type": [1, 5, 255],
                            "aid": [
                                1,
                                2,
                                3,
                                4,
                                5,
                                6,
                                7,
                                8,
                                9,
                                10,
                                11,
                                12,
                                13,
                                14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31,
                                32,
                                33,
                                34,
                                35,
                                36,
                                37,
                                38,
                                39,
                                40,
                                41,
                                42,
                                43,
                                44,
                                45,
                                46,
                                47,
                                48,
                                49,
                                50,
                                51,
                                52,
                                53,
                                54,
                                55,
                                56,
                                57,
                                58,
                                59,
                                60,
                                61,
                                62,
                                63,
                                64,
                                65,
                                66,
                                67,
                                68,
                                69,
                                70,
                                71,
                                72,
                                73,
                                74,
                                75,
                            ],
                            "conformers": [
                                {
                                    "x": [
                                        6.7437,
                                        7.6407,
                                        13.2337,
                                        9.0357,
                                        12.191,
                                        6.7568,
                                        8.2586,
                                        5.2534,
                                        6.7233,
                                        7.2574,
                                        9.7955,
                                        7.5588,
                                        8.8596,
                                        6.2562,
                                        9.7955,
                                        7.8502,
                                        10.594,
                                        5.9549,
                                        8.8261,
                                        8.5599,
                                        4.9872,
                                        8.5265,
                                        7.4491,
                                        11.5146,
                                        4.6858,
                                        7.5588,
                                        5.5855,
                                        10.5912,
                                        3.7182,
                                        7.2239,
                                        5.9214,
                                        6.2228,
                                        4.6858,
                                        3.7182,
                                        4.9537,
                                        2.8521,
                                        5.63,
                                        8.0418,
                                        12.3131,
                                        7.7995,
                                        2.9223,
                                        7.3791,
                                        2,
                                        8.3663,
                                        8.2781,
                                        10.1405,
                                        10.9316,
                                        8.9897,
                                        4.551,
                                        8.963,
                                        6.9329,
                                        7.0211,
                                        11.9681,
                                        11.177,
                                        5.1257,
                                        5.1697,
                                        6.0454,
                                        10.9667,
                                        11.0846,
                                        10.2157,
                                        4.5153,
                                        2.5421,
                                        2.3152,
                                        3.1622,
                                        6.1293,
                                        5.2625,
                                        5.1307,
                                        8.417,
                                        3.0007,
                                        7.736,
                                        6.7616,
                                        1.5066,
                                        1.9216,
                                        8.0082,
                                        13.7288,
                                    ],
                                    "y": [
                                        0.7222,
                                        -5.2892,
                                        0.2017,
                                        -4.2626,
                                        -1.1813,
                                        -0.2777,
                                        1.0918,
                                        1.0918,
                                        2.4613,
                                        -1.8464,
                                        0.6247,
                                        -0.8787,
                                        0.3568,
                                        -1.8464,
                                        1.6259,
                                        -2.6518,
                                        0.0227,
                                        -0.9122,
                                        1.8938,
                                        -0.6109,
                                        -0.6109,
                                        2.828,
                                        -3.5678,
                                        0.4132,
                                        0.3233,
                                        3.1293,
                                        -2.5881,
                                        2.2315,
                                        0.5912,
                                        4.0635,
                                        3.0958,
                                        4.0635,
                                        1.8603,
                                        1.5924,
                                        2.828,
                                        0.0912,
                                        4.8689,
                                        -4.3732,
                                        -0.1888,
                                        4.8812,
                                        2.1979,
                                        5.7886,
                                        1.8114,
                                        -2.9953,
                                        -2.2032,
                                        -0.4,
                                        -0.4974,
                                        -1.0577,
                                        -1.0515,
                                        3.2682,
                                        -3.2243,
                                        -4.0165,
                                        0.8359,
                                        0.9333,
                                        -2.1723,
                                        -3.048,
                                        -3.004,
                                        1.7382,
                                        2.607,
                                        2.7249,
                                        3.2664,
                                        0.6281,
                                        -0.2188,
                                        -0.4457,
                                        5.2364,
                                        5.3682,
                                        4.5014,
                                        4.8257,
                                        2.8129,
                                        6.2956,
                                        5.8441,
                                        2.1868,
                                        1.1963,
                                        -5.7886,
                                        -0.1715,
                                    ],
                                    "style": {
                                        "annotation": [
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                            8,
                                        ],
                                        "aid1": [
                                            6,
                                            6,
                                            7,
                                            7,
                                            8,
                                            8,
                                            9,
                                            9,
                                            10,
                                            10,
                                            11,
                                            11,
                                            12,
                                            13,
                                            14,
                                            15,
                                            18,
                                            19,
                                            21,
                                            22,
                                            31,
                                            33,
                                        ],
                                        "aid2": [
                                            12,
                                            18,
                                            13,
                                            19,
                                            25,
                                            33,
                                            26,
                                            31,
                                            12,
                                            14,
                                            13,
                                            15,
                                            20,
                                            20,
                                            18,
                                            19,
                                            21,
                                            22,
                                            25,
                                            26,
                                            35,
                                            35,
                                        ],
                                    },
                                }
                            ],
                        }
                    ],
                    "charge": 0,
                    "props": [
                        {
                            "urn": {
                                "label": "Compound",
                                "name": "Canonicalized",
                                "datatype": 5,
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 1},
                        },
                        {
                            "urn": {
                                "label": "Compound Complexity",
                                "datatype": 7,
                                "implementation": "E_COMPLEXITY",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 1010},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Acceptor",
                                "datatype": 5,
                                "implementation": "E_NHACCEPTORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 8},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Hydrogen Bond Donor",
                                "datatype": 5,
                                "implementation": "E_NHDONORS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 2},
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Rotatable Bond",
                                "datatype": 5,
                                "implementation": "E_NROTBONDS",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"ival": 8},
                        },
                        {
                            "urn": {
                                "label": "Fingerprint",
                                "name": "SubStructure Keys",
                                "datatype": 16,
                                "parameters": "extended 2",
                                "implementation": "E_SCREEN",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "binary": "00000371F07FB800000000200000000000000000000162C58B0000000000000000000001FE00001E00000800000C08819E0032C8B2081200A80324F24C00828020210220089821306498082072C0D0D1846408648000C8C80798D9F39E80000000000000000000000000000000000000000000"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Allowed",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "ferrous;3-[18-(2-carboxyethyl)-3,7,12,17-tetramethyl-8,13-divinyl-porphyrin-21,24-diid-2-yl]propanoic acid"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "CAS-like Style",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "3-[18-(2-carboxyethyl)-8,13-bis(ethenyl)-3,7,12,17-tetramethyl-2-porphyrin-21,24-diidyl]propanoic acid;iron(2+)"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Markup",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "3-[18-(2-carboxyethyl)-8,13-bis(ethenyl)-3,7,12,17-tetramethylporphyrin-21,24-diid-2-yl]propanoic acid;iron(2+)"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Preferred",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "3-[18-(2-carboxyethyl)-8,13-bis(ethenyl)-3,7,12,17-tetramethylporphyrin-21,24-diid-2-yl]propanoic acid;iron(2+)"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Systematic",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "3-[8,13-bis(ethenyl)-18-(3-hydroxy-3-oxopropyl)-3,7,12,17-tetramethyl-porphyrin-21,24-diid-2-yl]propanoic acid;iron(2+)"
                            },
                        },
                        {
                            "urn": {
                                "label": "IUPAC Name",
                                "name": "Traditional",
                                "datatype": 1,
                                "version": "2.7.0",
                                "software": "Lexichem TK",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "ferrous;3-[18-(2-carboxyethyl)-3,7,12,17-tetramethyl-8,13-divinyl-porphine-21,24-diid-2-yl]propionic acid"
                            },
                        },
                        {
                            "urn": {
                                "label": "InChI",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "InChI=1S/C34H34N4O4.Fe/c1-7-21-17(3)25-13-26-19(5)23(9-11-33(39)40)31(37-26)16-32-24(10-12-34(41)42)20(6)28(38-32)15-30-22(8-2)18(4)27(36-30)14-29(21)35-25;/h7-8,13-16H,1-2,9-12H2,3-6H3,(H4,35,36,37,38,39,40,41,42);/q;+2/p-2"
                            },
                        },
                        {
                            "urn": {
                                "label": "InChIKey",
                                "name": "Standard",
                                "datatype": 1,
                                "version": "1.0.6",
                                "software": "InChI",
                                "source": "iupac.org",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "KABFMIBPWCXCRK-UHFFFAOYSA-L"},
                        },
                        {
                            "urn": {
                                "label": "Mass",
                                "name": "Exact",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "616.177291"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Formula",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "C34H32FeN4O4"},
                        },
                        {
                            "urn": {
                                "label": "Molecular Weight",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "616.5"},
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Absolute",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2024.12.12",
                            },
                            "value": {
                                "sval": "CC1=C(C2=CC3=C(C(=C([N-]3)C=C4C(=C(C(=N4)C=C5C(=C(C(=N5)C=C1[N-]2)C)C=C)C)C=C)C)CCC(=O)O)CCC(=O)O.[Fe+2]"
                            },
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Canonical",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "CC1=C(C2=CC3=C(C(=C([N-]3)C=C4C(=C(C(=N4)C=C5C(=C(C(=N5)C=C1[N-]2)C)C=C)C)C=C)C)CCC(=O)O)CCC(=O)O.[Fe+2]"
                            },
                        },
                        {
                            "urn": {
                                "label": "SMILES",
                                "name": "Isomeric",
                                "datatype": 1,
                                "version": "2.3.0",
                                "software": "OEChem",
                                "source": "OpenEye Scientific Software",
                                "release": "2021.10.14",
                            },
                            "value": {
                                "sval": "CC1=C(C2=CC3=C(C(=C([N-]3)C=C4C(=C(C(=N4)C=C5C(=C(C(=N5)C=C1[N-]2)C)C=C)C)C=C)C)CCC(=O)O)CCC(=O)O.[Fe+2]"
                            },
                        },
                        {
                            "urn": {
                                "label": "Topological",
                                "name": "Polar Surface Area",
                                "datatype": 7,
                                "implementation": "E_TPSA",
                                "version": "3.4.8.18",
                                "software": "Cactvs",
                                "source": "Xemistry GmbH",
                                "release": "2021.10.14",
                            },
                            "value": {"fval": 102},
                        },
                        {
                            "urn": {
                                "label": "Weight",
                                "name": "MonoIsotopic",
                                "datatype": 1,
                                "version": "2.2",
                                "software": "PubChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2021.10.14",
                            },
                            "value": {"sval": "616.177291"},
                        },
                    ],
                    "count": {
                        "heavy_atom": 43,
                        "atom_chiral": 0,
                        "atom_chiral_def": 0,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 2,
                        "tautomers": -1,
                    },
                }
            ]
        }

    @pytest.fixture
    def heme_3d_file_data(self):
        return {
            "PC_Compounds": [
                {
                    "id": {"id": {"cid": 4971}},
                    "atoms": {
                        "aid": [
                            1,
                            2,
                            3,
                            4,
                            5,
                            6,
                            7,
                            8,
                            9,
                            10,
                            11,
                            12,
                            13,
                            14,
                            15,
                            16,
                            17,
                            18,
                            19,
                            20,
                            21,
                            22,
                            23,
                            24,
                            25,
                            26,
                            27,
                            28,
                            29,
                            30,
                            31,
                            32,
                            33,
                            34,
                            35,
                            36,
                            37,
                            38,
                            39,
                            40,
                            41,
                            42,
                            43,
                            44,
                            45,
                            46,
                            47,
                            48,
                            49,
                            50,
                            51,
                            52,
                            53,
                            54,
                            55,
                            56,
                            57,
                            58,
                            59,
                            60,
                            61,
                            62,
                            63,
                            64,
                            65,
                            66,
                            67,
                            68,
                            69,
                            70,
                            71,
                            72,
                            73,
                            74,
                            75,
                            76,
                        ],
                        "element": [
                            8,
                            8,
                            8,
                            8,
                            7,
                            7,
                            7,
                            7,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            6,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                    },
                    "bonds": {
                        "aid1": [
                            1,
                            1,
                            2,
                            2,
                            3,
                            4,
                            5,
                            5,
                            5,
                            6,
                            6,
                            6,
                            7,
                            7,
                            8,
                            8,
                            9,
                            9,
                            9,
                            10,
                            10,
                            10,
                            11,
                            12,
                            12,
                            13,
                            14,
                            14,
                            15,
                            16,
                            17,
                            17,
                            18,
                            18,
                            19,
                            19,
                            20,
                            20,
                            21,
                            21,
                            21,
                            22,
                            22,
                            22,
                            23,
                            24,
                            24,
                            25,
                            25,
                            26,
                            27,
                            28,
                            29,
                            30,
                            31,
                            31,
                            31,
                            32,
                            32,
                            32,
                            33,
                            33,
                            33,
                            34,
                            34,
                            34,
                            35,
                            35,
                            35,
                            36,
                            36,
                            36,
                            37,
                            37,
                            38,
                            38,
                            41,
                            41,
                            42,
                            42,
                        ],
                        "aid2": [
                            39,
                            75,
                            40,
                            76,
                            39,
                            40,
                            17,
                            20,
                            50,
                            18,
                            19,
                            51,
                            11,
                            15,
                            13,
                            16,
                            11,
                            12,
                            21,
                            13,
                            14,
                            22,
                            23,
                            15,
                            31,
                            23,
                            16,
                            34,
                            28,
                            29,
                            24,
                            28,
                            25,
                            30,
                            27,
                            29,
                            26,
                            30,
                            32,
                            43,
                            44,
                            33,
                            45,
                            46,
                            47,
                            26,
                            35,
                            27,
                            36,
                            37,
                            38,
                            48,
                            49,
                            52,
                            53,
                            54,
                            55,
                            39,
                            56,
                            57,
                            40,
                            58,
                            59,
                            60,
                            61,
                            62,
                            63,
                            64,
                            65,
                            66,
                            67,
                            68,
                            41,
                            69,
                            42,
                            70,
                            71,
                            72,
                            73,
                            74,
                        ],
                        "order": [
                            1,
                            1,
                            1,
                            1,
                            2,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            2,
                            1,
                            2,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            1,
                            2,
                            1,
                            2,
                            1,
                            1,
                            1,
                            1,
                            1,
                        ],
                    },
                    "coords": [
                        {
                            "type": [2, 5, 10],
                            "aid": [
                                1,
                                2,
                                3,
                                4,
                                5,
                                6,
                                7,
                                8,
                                9,
                                10,
                                11,
                                12,
                                13,
                                14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31,
                                32,
                                33,
                                34,
                                35,
                                36,
                                37,
                                38,
                                39,
                                40,
                                41,
                                42,
                                43,
                                44,
                                45,
                                46,
                                47,
                                48,
                                49,
                                50,
                                51,
                                52,
                                53,
                                54,
                                55,
                                56,
                                57,
                                58,
                                59,
                                60,
                                61,
                                62,
                                63,
                                64,
                                65,
                                66,
                                67,
                                68,
                                69,
                                70,
                                71,
                                72,
                                73,
                                74,
                                75,
                                76,
                            ],
                            "conformers": [
                                {
                                    "x": [
                                        7.1385,
                                        5.7615,
                                        6.7154,
                                        6.1372,
                                        -2.525,
                                        -2.6939,
                                        0.4051,
                                        0.1811,
                                        2.507,
                                        2.0591,
                                        1.6482,
                                        1.6304,
                                        1.5429,
                                        1.0549,
                                        0.3143,
                                        -0.1068,
                                        -2.0505,
                                        -3.9963,
                                        -2.5688,
                                        -3.7828,
                                        3.9475,
                                        3.5095,
                                        2.2658,
                                        -3.0486,
                                        -4.7892,
                                        -4.1304,
                                        -3.9471,
                                        -0.7823,
                                        -1.4551,
                                        -4.5176,
                                        1.9005,
                                        4.852,
                                        3.9112,
                                        1.0259,
                                        -2.9926,
                                        -6.2814,
                                        -5.36,
                                        -4.3596,
                                        6.3128,
                                        5.3729,
                                        -6.1715,
                                        -4.6339,
                                        4.1938,
                                        4.1687,
                                        3.7406,
                                        4.1341,
                                        3.3403,
                                        -0.7083,
                                        -1.5138,
                                        -2.0287,
                                        -1.9035,
                                        -5.5979,
                                        1.2897,
                                        2.9482,
                                        1.6775,
                                        4.6712,
                                        4.6518,
                                        3.3272,
                                        3.7327,
                                        2.0137,
                                        0.3499,
                                        0.6873,
                                        -3.5447,
                                        -3.4318,
                                        -1.9644,
                                        -6.7151,
                                        -6.61,
                                        -6.7014,
                                        -5.693,
                                        -4.4411,
                                        -7.0854,
                                        -5.9398,
                                        -4.9394,
                                        -4.5621,
                                        8.0834,
                                        6.7157,
                                    ],
                                    "y": [
                                        2.705,
                                        -3.2503,
                                        2.1599,
                                        -3.4886,
                                        1.9272,
                                        -1.118,
                                        1.517,
                                        -1.3404,
                                        2.3377,
                                        -2.6167,
                                        1.2058,
                                        3.3517,
                                        -1.2639,
                                        -3.502,
                                        2.872,
                                        -2.6087,
                                        3.1577,
                                        -0.6924,
                                        -2.4592,
                                        1.7074,
                                        2.2748,
                                        -2.9072,
                                        -0.1348,
                                        3.753,
                                        -1.9053,
                                        2.8451,
                                        -2.9601,
                                        3.6329,
                                        -3.2035,
                                        0.5263,
                                        4.7807,
                                        2.5394,
                                        -2.9257,
                                        -4.9791,
                                        5.1012,
                                        -1.8735,
                                        3.0491,
                                        -4.3097,
                                        2.4348,
                                        -3.2588,
                                        2.1311,
                                        -5.2115,
                                        1.3129,
                                        3.0159,
                                        -3.8863,
                                        -2.2066,
                                        -0.1671,
                                        4.7057,
                                        -4.2667,
                                        1.2921,
                                        -0.5315,
                                        0.6383,
                                        5.1008,
                                        4.9486,
                                        5.4274,
                                        3.5474,
                                        1.8113,
                                        -3.6772,
                                        -1.9441,
                                        -5.3942,
                                        -5.3061,
                                        -5.4128,
                                        5.8188,
                                        5.0997,
                                        5.4627,
                                        -1.5506,
                                        -1.1876,
                                        -2.8571,
                                        4.0826,
                                        -4.5822,
                                        2.4544,
                                        1.0737,
                                        -6.2155,
                                        -4.9765,
                                        2.6451,
                                        -3.456,
                                    ],
                                    "z": [
                                        -0.6711,
                                        -2.9408,
                                        1.493,
                                        -0.7132,
                                        0.2862,
                                        0.2758,
                                        0.2379,
                                        0.4974,
                                        0.8711,
                                        0.1996,
                                        0.4657,
                                        0.8618,
                                        0.3342,
                                        0.2769,
                                        0.4652,
                                        0.4631,
                                        -0.111,
                                        0.2747,
                                        0.54,
                                        -0.2302,
                                        1.2062,
                                        0.0057,
                                        0.3202,
                                        -0.8571,
                                        0.5602,
                                        -0.9341,
                                        0.7181,
                                        0.3107,
                                        0.6248,
                                        0.0526,
                                        1.1965,
                                        0.0033,
                                        -1.4638,
                                        0.1919,
                                        -1.4661,
                                        0.6439,
                                        -1.6044,
                                        1.0073,
                                        0.3698,
                                        -1.6419,
                                        -2.1847,
                                        0.0645,
                                        1.6711,
                                        1.9856,
                                        0.4471,
                                        0.5729,
                                        0.1855,
                                        0.4708,
                                        0.8304,
                                        0.8961,
                                        0.0596,
                                        0.092,
                                        2.0471,
                                        1.4639,
                                        0.3414,
                                        -0.3875,
                                        -0.7907,
                                        -2.0076,
                                        -1.9173,
                                        -0.029,
                                        -0.6044,
                                        1.1379,
                                        -0.8503,
                                        -2.4692,
                                        -1.568,
                                        -0.3082,
                                        1.4317,
                                        0.8758,
                                        -1.6921,
                                        2.0553,
                                        -2.6733,
                                        -2.2183,
                                        0.3391,
                                        -0.9923,
                                        -0.4143,
                                        -3.0389,
                                    ],
                                    "data": [
                                        {
                                            "urn": {
                                                "label": "Conformer",
                                                "name": "ID",
                                                "datatype": 11,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2009.12.11",
                                            },
                                            "value": {"sval": "0000136B00000001"},
                                        },
                                        {
                                            "urn": {
                                                "label": "Energy",
                                                "name": "MMFF94 NoEstat",
                                                "datatype": 7,
                                                "version": "1.7.2",
                                                "software": "Szybki",
                                                "source": "openeye.com",
                                                "release": "2012.11.26",
                                            },
                                            "value": {"fval": 113.2274},
                                        },
                                        {
                                            "urn": {
                                                "label": "Feature",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.11.26",
                                            },
                                            "value": {"fval": 91.467},
                                        },
                                        {
                                            "urn": {
                                                "label": "Fingerprint",
                                                "name": "Shape",
                                                "datatype": 2,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.11.26",
                                            },
                                            "value": {
                                                "slist": [
                                                    "10190206 1 17837227974003681670",
                                                    "11204353 107 18411981321871663070",
                                                    "11227688 84 18272077340465287277",
                                                    "11513181 2 18200582696201270198",
                                                    "12645989 146 17836087049689112414",
                                                    "14117953 113 18193272117098521597",
                                                    "14415360 78 17829314801318578837",
                                                    "14725015 67 17975403930735511203",
                                                    "14747282 125 18270417013720271431",
                                                    "15320467 1 18265329685113451249",
                                                    "15400415 2 18120079603191075997",
                                                    "15950262 2 15216139600569668141",
                                                    "15968369 26 18269254804497563256",
                                                    "16112460 7 18271817761242498769",
                                                    "20028762 73 17839462528964120378",
                                                    "20609170 92 18407757040677506604",
                                                    "20775438 99 18125412290218664175",
                                                    "21033648 144 18411981399492219519",
                                                    "21792965 2 18335686231985395930",
                                                    "22311459 1 18194965377705692746",
                                                    "25223398 141 18115581702694767268",
                                                    "4403749 210 18121193618807126224",
                                                    "50150288 127 16844182142828248609",
                                                    "5171179 24 18413392037791061314",
                                                    "5265222 85 17979079602809049044",
                                                    "5776283 40 18263933124382620565",
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Multipoles",
                                                "datatype": 8,
                                                "version": "1.8.3",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.11.26",
                                            },
                                            "value": {
                                                "fvec": [
                                                    820.94,
                                                    15.1,
                                                    9.26,
                                                    1.44,
                                                    10,
                                                    1.8,
                                                    0.92,
                                                    0.13,
                                                    4.37,
                                                    -1.32,
                                                    0.9,
                                                    0.8,
                                                    -0.04,
                                                    7.12,
                                                ]
                                            },
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Self Overlap",
                                                "datatype": 7,
                                                "version": "2.1",
                                                "software": "PubChem",
                                                "source": "ncbi.nlm.nih.gov",
                                                "release": "2012.11.26",
                                            },
                                            "value": {"fval": 1798.142},
                                        },
                                        {
                                            "urn": {
                                                "label": "Shape",
                                                "name": "Volume",
                                                "datatype": 7,
                                                "version": "1.8.3",
                                                "software": "OEShape",
                                                "source": "openeye.com",
                                                "release": "2012.11.26",
                                            },
                                            "value": {"fval": 447.4},
                                        },
                                    ],
                                }
                            ],
                            "data": [
                                {
                                    "urn": {
                                        "label": "Conformer",
                                        "name": "RMSD",
                                        "datatype": 7,
                                        "release": "2009.12.11",
                                    },
                                    "value": {"fval": 1},
                                },
                                {
                                    "urn": {
                                        "label": "Diverse Conformer",
                                        "name": "ID List",
                                        "datatype": 6,
                                        "release": "2010.05.05",
                                    },
                                    "value": {"ivec": [1, 4, 9, 8, 6, 7, 2, 5, 3]},
                                },
                            ],
                        }
                    ],
                    "props": [
                        {
                            "urn": {
                                "label": "Charge",
                                "name": "MMFF94 Partial",
                                "datatype": 2,
                                "version": "1.9.0",
                                "software": "OEChem",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {
                                "slist": [
                                    "55",
                                    "1 -0.65",
                                    "10 -0.14",
                                    "11 0.42",
                                    "12 -0.14",
                                    "13 0.17",
                                    "14 -0.12",
                                    "15 0.17",
                                    "16 0.42",
                                    "17 -0.2",
                                    "18 0.1",
                                    "19 0.1",
                                    "2 -0.65",
                                    "20 -0.2",
                                    "21 0.14",
                                    "22 0.14",
                                    "23 -0.14",
                                    "24 -0.18",
                                    "25 -0.14",
                                    "26 -0.05",
                                    "28 -0.11",
                                    "29 -0.14",
                                    "3 -0.57",
                                    "30 -0.11",
                                    "31 0.14",
                                    "32 0.06",
                                    "33 0.06",
                                    "34 0.14",
                                    "35 0.18",
                                    "36 0.14",
                                    "37 -0.1",
                                    "38 -0.15",
                                    "39 0.66",
                                    "4 -0.57",
                                    "40 0.66",
                                    "41 -0.3",
                                    "42 -0.3",
                                    "47 0.15",
                                    "48 0.15",
                                    "49 0.15",
                                    "5 0.03",
                                    "50 0.27",
                                    "51 0.4",
                                    "52 0.15",
                                    "6 -0.6",
                                    "69 0.15",
                                    "7 -0.62",
                                    "70 0.15",
                                    "71 0.15",
                                    "72 0.15",
                                    "73 0.15",
                                    "74 0.15",
                                    "75 0.5",
                                    "76 0.5",
                                    "8 -0.62",
                                    "9 -0.12",
                                ]
                            },
                        },
                        {
                            "urn": {
                                "label": "Count",
                                "name": "Effective Rotor",
                                "datatype": 7,
                                "version": "1.9.0",
                                "software": "OEChem",
                                "source": "ncbi.nlm.nih.gov",
                                "release": "2012.11.26",
                            },
                            "value": {"fval": 8},
                        },
                        {
                            "urn": {
                                "label": "Features",
                                "name": "Pharmacophore",
                                "datatype": 2,
                                "parameters": "ImplicitMillsDean merged",
                                "version": "1.8.3",
                                "software": "OEShape",
                                "source": "openeye.com",
                                "release": "2012.11.26",
                            },
                            "value": {
                                "slist": [
                                    "18",
                                    "1 1 acceptor",
                                    "1 2 acceptor",
                                    "1 3 acceptor",
                                    "1 4 acceptor",
                                    "1 41 hydrophobe",
                                    "1 42 hydrophobe",
                                    "1 5 cation",
                                    "1 5 donor",
                                    "1 6 cation",
                                    "1 6 donor",
                                    "1 7 acceptor",
                                    "1 8 acceptor",
                                    "3 1 3 39 anion",
                                    "3 2 4 40 anion",
                                    "5 5 17 20 24 26 rings",
                                    "5 6 18 19 25 27 rings",
                                    "5 7 9 11 12 15 rings",
                                    "5 8 10 13 14 16 rings",
                                ]
                            },
                        },
                    ],
                    "count": {
                        "heavy_atom": 42,
                        "atom_chiral": 0,
                        "atom_chiral_def": 0,
                        "atom_chiral_undef": 0,
                        "bond_chiral": 0,
                        "bond_chiral_def": 0,
                        "bond_chiral_undef": 0,
                        "isotope_atom": 0,
                        "covalent_unit": 1,
                        "tautomers": 6,
                    },
                }
            ]
        }

    @pytest.fixture
    def acetone_2d_molecule_data(self):
        return [
            (
                {
                    1: {"element": "O", "coords": np.array([3.732, 0.75, 0.0])},
                    2: {"element": "C", "coords": np.array([2.866, 0.25, 0.0])},
                    3: {"element": "C", "coords": np.array([2.0, 0.75, 0.0])},
                    4: {"element": "C", "coords": np.array([2.866, -0.75, 0.0])},
                    5: {"element": "H", "coords": np.array([2.31, 1.2869, 0.0])},
                    6: {"element": "H", "coords": np.array([1.4631, 1.06, 0.0])},
                    7: {"element": "H", "coords": np.array([1.69, 0.2131, 0.0])},
                    8: {"element": "H", "coords": np.array([2.246, -0.75, 0.0])},
                    9: {"element": "H", "coords": np.array([2.866, -1.37, 0.0])},
                    10: {"element": "H", "coords": np.array([3.486, -0.75, 0.0])},
                },
                {
                    0: {"from_atom_index": 1, "to_atom_index": 2, "bond_type": 2},
                    1: {"from_atom_index": 2, "to_atom_index": 3, "bond_type": 1},
                    2: {"from_atom_index": 2, "to_atom_index": 4, "bond_type": 1},
                    3: {"from_atom_index": 3, "to_atom_index": 5, "bond_type": 1},
                    4: {"from_atom_index": 3, "to_atom_index": 6, "bond_type": 1},
                    5: {"from_atom_index": 3, "to_atom_index": 7, "bond_type": 1},
                    6: {"from_atom_index": 4, "to_atom_index": 8, "bond_type": 1},
                    7: {"from_atom_index": 4, "to_atom_index": 9, "bond_type": 1},
                    8: {"from_atom_index": 4, "to_atom_index": 10, "bond_type": 1},
                },
            )
        ]

    @pytest.fixture
    def acetone_3d_molecule_data(self):
        return [
            (
                {
                    1: {
                        "element": "O",
                        "coords": np.array([3.0000e-04, -1.3171e00, -2.0000e-04]),
                    },
                    2: {"element": "C", "coords": np.array([0.0, -0.0872, 0.0006])},
                    3: {
                        "element": "C",
                        "coords": np.array([1.281e00, 7.024e-01, -2.000e-04]),
                    },
                    4: {
                        "element": "C",
                        "coords": np.array([-1.2813e00, 7.0190e-01, -2.0000e-04]),
                    },
                    5: {"element": "H", "coords": np.array([1.3279, 1.3235, -0.898])},
                    6: {"element": "H", "coords": np.array([1.326, 1.3282, 0.8945])},
                    7: {"element": "H", "coords": np.array([2.1351, 0.0196, 0.0027])},
                    8: {"element": "H", "coords": np.array([-2.1352, 0.0187, 0.0027])},
                    9: {"element": "H", "coords": np.array([-1.3284, 1.323, -0.898])},
                    10: {"element": "H", "coords": np.array([-1.3266, 1.3278, 0.8945])},
                },
                {
                    0: {"from_atom_index": 1, "to_atom_index": 2, "bond_type": 2},
                    1: {"from_atom_index": 2, "to_atom_index": 3, "bond_type": 1},
                    2: {"from_atom_index": 2, "to_atom_index": 4, "bond_type": 1},
                    3: {"from_atom_index": 3, "to_atom_index": 5, "bond_type": 1},
                    4: {"from_atom_index": 3, "to_atom_index": 6, "bond_type": 1},
                    5: {"from_atom_index": 3, "to_atom_index": 7, "bond_type": 1},
                    6: {"from_atom_index": 4, "to_atom_index": 8, "bond_type": 1},
                    7: {"from_atom_index": 4, "to_atom_index": 9, "bond_type": 1},
                    8: {"from_atom_index": 4, "to_atom_index": 10, "bond_type": 1},
                },
            )
        ]

    @pytest.fixture
    def morphine_2d_molecule_data(self):
        return [
            (
                {
                    1: {"element": "O", "coords": np.array([2.2314, 0.0528, 0.0])},
                    2: {"element": "O", "coords": np.array([2.0, -2.4021, 0.0])},
                    3: {"element": "O", "coords": np.array([2.0, 2.4021, 0.0])},
                    4: {"element": "N", "coords": np.array([6.1607, -0.9511, 0.0])},
                    5: {"element": "C", "coords": np.array([3.6897, -0.4755, 0.0])},
                    6: {"element": "C", "coords": np.array([4.5133, -0.9511, 0.0])},
                    7: {"element": "C", "coords": np.array([5.337, -0.4755, 0.0])},
                    8: {"element": "C", "coords": np.array([2.866, -0.9511, 0.0])},
                    9: {"element": "C", "coords": np.array([4.2392, 0.2219, 0.0])},
                    10: {"element": "C", "coords": np.array([3.6897, 0.4755, 0.0])},
                    11: {"element": "C", "coords": np.array([5.337, 0.4755, 0.0])},
                    12: {"element": "C", "coords": np.array([5.5918, 0.2219, 0.0])},
                    13: {"element": "C", "coords": np.array([4.5133, 0.9511, 0.0])},
                    14: {"element": "C", "coords": np.array([2.866, -1.9022, 0.0])},
                    15: {"element": "C", "coords": np.array([4.5133, -1.9022, 0.0])},
                    16: {"element": "C", "coords": np.array([2.866, 0.9511, 0.0])},
                    17: {"element": "C", "coords": np.array([3.6897, -2.3777, 0.0])},
                    18: {"element": "C", "coords": np.array([6.8418, -1.6832, 0.0])},
                    19: {"element": "C", "coords": np.array([4.5133, 1.9022, 0.0])},
                    20: {"element": "C", "coords": np.array([2.866, 1.9022, 0.0])},
                    21: {"element": "C", "coords": np.array([3.6897, 2.3777, 0.0])},
                    22: {"element": "H", "coords": np.array([5.0597, -1.6022, 0.0])},
                    23: {"element": "H", "coords": np.array([5.6284, -1.274, 0.0])},
                    24: {"element": "H", "coords": np.array([2.0496, -1.1875, 0.0])},
                    25: {"element": "H", "coords": np.array([4.376, 0.8266, 0.0])},
                    26: {"element": "H", "coords": np.array([3.6795, 0.4887, 0.0])},
                    27: {"element": "H", "coords": np.array([5.9476, 0.3679, 0.0])},
                    28: {"element": "H", "coords": np.array([5.549, 1.0581, 0.0])},
                    29: {"element": "H", "coords": np.array([6.184, 0.4057, 0.0])},
                    30: {"element": "H", "coords": np.array([5.4989, 0.8349, 0.0])},
                    31: {"element": "H", "coords": np.array([2.866, -2.5222, 0.0])},
                    32: {"element": "H", "coords": np.array([5.0503, -2.2122, 0.0])},
                    33: {"element": "H", "coords": np.array([3.6897, -2.9977, 0.0])},
                    34: {"element": "H", "coords": np.array([6.3879, -2.1055, 0.0])},
                    35: {"element": "H", "coords": np.array([7.2641, -2.1371, 0.0])},
                    36: {"element": "H", "coords": np.array([7.2957, -1.2609, 0.0])},
                    37: {"element": "H", "coords": np.array([5.0503, 2.2122, 0.0])},
                    38: {"element": "H", "coords": np.array([3.6897, 2.9977, 0.0])},
                    39: {"element": "H", "coords": np.array([2.0, -3.0222, 0.0])},
                    40: {"element": "H", "coords": np.array([2.0, 3.0222, 0.0])},
                },
                {
                    0: {"from_atom_index": 1, "to_atom_index": 8, "bond_type": 1},
                    1: {"from_atom_index": 1, "to_atom_index": 16, "bond_type": 1},
                    2: {"from_atom_index": 2, "to_atom_index": 14, "bond_type": 1},
                    3: {"from_atom_index": 2, "to_atom_index": 39, "bond_type": 1},
                    4: {"from_atom_index": 3, "to_atom_index": 20, "bond_type": 1},
                    5: {"from_atom_index": 3, "to_atom_index": 40, "bond_type": 1},
                    6: {"from_atom_index": 4, "to_atom_index": 7, "bond_type": 1},
                    7: {"from_atom_index": 4, "to_atom_index": 12, "bond_type": 1},
                    8: {"from_atom_index": 4, "to_atom_index": 18, "bond_type": 1},
                    9: {"from_atom_index": 5, "to_atom_index": 6, "bond_type": 1},
                    10: {"from_atom_index": 5, "to_atom_index": 8, "bond_type": 1},
                    11: {"from_atom_index": 5, "to_atom_index": 9, "bond_type": 1},
                    12: {"from_atom_index": 5, "to_atom_index": 10, "bond_type": 1},
                    13: {"from_atom_index": 6, "to_atom_index": 7, "bond_type": 1},
                    14: {"from_atom_index": 6, "to_atom_index": 15, "bond_type": 1},
                    15: {"from_atom_index": 6, "to_atom_index": 22, "bond_type": 1},
                    16: {"from_atom_index": 7, "to_atom_index": 11, "bond_type": 1},
                    17: {"from_atom_index": 7, "to_atom_index": 23, "bond_type": 1},
                    18: {"from_atom_index": 8, "to_atom_index": 14, "bond_type": 1},
                    19: {"from_atom_index": 8, "to_atom_index": 24, "bond_type": 1},
                    20: {"from_atom_index": 9, "to_atom_index": 12, "bond_type": 1},
                    21: {"from_atom_index": 9, "to_atom_index": 25, "bond_type": 1},
                    22: {"from_atom_index": 9, "to_atom_index": 26, "bond_type": 1},
                    23: {"from_atom_index": 10, "to_atom_index": 13, "bond_type": 2},
                    24: {"from_atom_index": 10, "to_atom_index": 16, "bond_type": 1},
                    25: {"from_atom_index": 11, "to_atom_index": 13, "bond_type": 1},
                    26: {"from_atom_index": 11, "to_atom_index": 27, "bond_type": 1},
                    27: {"from_atom_index": 11, "to_atom_index": 28, "bond_type": 1},
                    28: {"from_atom_index": 12, "to_atom_index": 29, "bond_type": 1},
                    29: {"from_atom_index": 12, "to_atom_index": 30, "bond_type": 1},
                    30: {"from_atom_index": 13, "to_atom_index": 19, "bond_type": 1},
                    31: {"from_atom_index": 14, "to_atom_index": 17, "bond_type": 1},
                    32: {"from_atom_index": 14, "to_atom_index": 31, "bond_type": 1},
                    33: {"from_atom_index": 15, "to_atom_index": 17, "bond_type": 2},
                    34: {"from_atom_index": 15, "to_atom_index": 32, "bond_type": 1},
                    35: {"from_atom_index": 16, "to_atom_index": 20, "bond_type": 2},
                    36: {"from_atom_index": 17, "to_atom_index": 33, "bond_type": 1},
                    37: {"from_atom_index": 18, "to_atom_index": 34, "bond_type": 1},
                    38: {"from_atom_index": 18, "to_atom_index": 35, "bond_type": 1},
                    39: {"from_atom_index": 18, "to_atom_index": 36, "bond_type": 1},
                    40: {"from_atom_index": 19, "to_atom_index": 21, "bond_type": 2},
                    41: {"from_atom_index": 19, "to_atom_index": 37, "bond_type": 1},
                    42: {"from_atom_index": 20, "to_atom_index": 21, "bond_type": 1},
                    43: {"from_atom_index": 21, "to_atom_index": 38, "bond_type": 1},
                },
            )
        ]

    @pytest.fixture
    def morphine_3d_molecule_data(self):
        return [
            (
                {
                    1: {"element": "O", "coords": np.array([-1.993, -0.474, 1.2005])},
                    2: {
                        "element": "O",
                        "coords": np.array([-2.7826, -2.5168, -0.2218]),
                    },
                    3: {"element": "O", "coords": np.array([-3.622, 1.8421, 0.5579])},
                    4: {"element": "N", "coords": np.array([3.1777, -0.0101, 0.4474])},
                    5: {"element": "C", "coords": np.array([0.3699, -0.7149, 0.6616])},
                    6: {"element": "C", "coords": np.array([1.2913, -1.3046, -0.417])},
                    7: {"element": "C", "coords": np.array([2.3441, -0.2023, -0.764])},
                    8: {"element": "C", "coords": np.array([-0.9377, -1.475, 0.9848])},
                    9: {"element": "C", "coords": np.array([1.1988, -0.3907, 1.9201])},
                    10: {"element": "C", "coords": np.array([-0.2516, 0.5302, 0.1205])},
                    11: {"element": "C", "coords": np.array([1.6887, 1.1052, -1.3279])},
                    12: {"element": "C", "coords": np.array([2.4315, 0.4754, 1.6126])},
                    13: {"element": "C", "coords": np.array([0.3384, 1.4306, -0.748])},
                    14: {
                        "element": "C",
                        "coords": np.array([-1.3631, -2.5067, -0.0924]),
                    },
                    15: {
                        "element": "C",
                        "coords": np.array([0.5066, -1.8183, -1.5971]),
                    },
                    16: {"element": "C", "coords": np.array([-1.5672, 0.6306, 0.5136])},
                    17: {
                        "element": "C",
                        "coords": np.array([-0.7155, -2.3492, -1.4425]),
                    },
                    18: {"element": "C", "coords": np.array([4.3733, 0.7916, 0.2084])},
                    19: {
                        "element": "C",
                        "coords": np.array([-0.4184, 2.5415, -1.1246]),
                    },
                    20: {"element": "C", "coords": np.array([-2.331, 1.7217, 0.162])},
                    21: {
                        "element": "C",
                        "coords": np.array([-1.7382, 2.6936, -0.6541]),
                    },
                    22: {
                        "element": "H",
                        "coords": np.array([1.8278, -2.1759, -0.0118]),
                    },
                    23: {
                        "element": "H",
                        "coords": np.array([3.0029, -0.6035, -1.5465]),
                    },
                    24: {
                        "element": "H",
                        "coords": np.array([-0.8451, -2.0128, 1.9373]),
                    },
                    25: {"element": "H", "coords": np.array([1.5366, -1.3335, 2.3712])},
                    26: {"element": "H", "coords": np.array([0.5899, 0.1174, 2.679])},
                    27: {"element": "H", "coords": np.array([1.5474, 0.9596, -2.4075])},
                    28: {"element": "H", "coords": np.array([2.353, 1.968, -1.2194])},
                    29: {"element": "H", "coords": np.array([2.1271, 1.5205, 1.476])},
                    30: {"element": "H", "coords": np.array([3.0801, 0.4584, 2.4975])},
                    31: {
                        "element": "H",
                        "coords": np.array([-1.0772, -3.5067, 0.2593]),
                    },
                    32: {
                        "element": "H",
                        "coords": np.array([0.9601, -1.7947, -2.5831]),
                    },
                    33: {"element": "H", "coords": np.array([-1.23, -2.7505, -2.3109])},
                    34: {"element": "H", "coords": np.array([4.15, 1.8479, 0.0287])},
                    35: {"element": "H", "coords": np.array([4.938, 0.4055, -0.6472])},
                    36: {"element": "H", "coords": np.array([5.0444, 0.7352, 1.073])},
                    37: {
                        "element": "H",
                        "coords": np.array([-0.0062, 3.2824, -1.8043]),
                    },
                    38: {
                        "element": "H",
                        "coords": np.array([-2.3121, 3.5638, -0.9645]),
                    },
                    39: {
                        "element": "H",
                        "coords": np.array([-3.1557, -2.6446, 0.6672]),
                    },
                    40: {"element": "H", "coords": np.array([-3.8483, 1.0686, 1.1031])},
                },
                {
                    0: {"from_atom_index": 1, "to_atom_index": 8, "bond_type": 1},
                    1: {"from_atom_index": 1, "to_atom_index": 16, "bond_type": 1},
                    2: {"from_atom_index": 2, "to_atom_index": 14, "bond_type": 1},
                    3: {"from_atom_index": 2, "to_atom_index": 39, "bond_type": 1},
                    4: {"from_atom_index": 3, "to_atom_index": 20, "bond_type": 1},
                    5: {"from_atom_index": 3, "to_atom_index": 40, "bond_type": 1},
                    6: {"from_atom_index": 4, "to_atom_index": 7, "bond_type": 1},
                    7: {"from_atom_index": 4, "to_atom_index": 12, "bond_type": 1},
                    8: {"from_atom_index": 4, "to_atom_index": 18, "bond_type": 1},
                    9: {"from_atom_index": 5, "to_atom_index": 6, "bond_type": 1},
                    10: {"from_atom_index": 5, "to_atom_index": 8, "bond_type": 1},
                    11: {"from_atom_index": 5, "to_atom_index": 9, "bond_type": 1},
                    12: {"from_atom_index": 5, "to_atom_index": 10, "bond_type": 1},
                    13: {"from_atom_index": 6, "to_atom_index": 7, "bond_type": 1},
                    14: {"from_atom_index": 6, "to_atom_index": 15, "bond_type": 1},
                    15: {"from_atom_index": 6, "to_atom_index": 22, "bond_type": 1},
                    16: {"from_atom_index": 7, "to_atom_index": 11, "bond_type": 1},
                    17: {"from_atom_index": 7, "to_atom_index": 23, "bond_type": 1},
                    18: {"from_atom_index": 8, "to_atom_index": 14, "bond_type": 1},
                    19: {"from_atom_index": 8, "to_atom_index": 24, "bond_type": 1},
                    20: {"from_atom_index": 9, "to_atom_index": 12, "bond_type": 1},
                    21: {"from_atom_index": 9, "to_atom_index": 25, "bond_type": 1},
                    22: {"from_atom_index": 9, "to_atom_index": 26, "bond_type": 1},
                    23: {"from_atom_index": 10, "to_atom_index": 13, "bond_type": 2},
                    24: {"from_atom_index": 10, "to_atom_index": 16, "bond_type": 1},
                    25: {"from_atom_index": 11, "to_atom_index": 13, "bond_type": 1},
                    26: {"from_atom_index": 11, "to_atom_index": 27, "bond_type": 1},
                    27: {"from_atom_index": 11, "to_atom_index": 28, "bond_type": 1},
                    28: {"from_atom_index": 12, "to_atom_index": 29, "bond_type": 1},
                    29: {"from_atom_index": 12, "to_atom_index": 30, "bond_type": 1},
                    30: {"from_atom_index": 13, "to_atom_index": 19, "bond_type": 1},
                    31: {"from_atom_index": 14, "to_atom_index": 17, "bond_type": 1},
                    32: {"from_atom_index": 14, "to_atom_index": 31, "bond_type": 1},
                    33: {"from_atom_index": 15, "to_atom_index": 17, "bond_type": 2},
                    34: {"from_atom_index": 15, "to_atom_index": 32, "bond_type": 1},
                    35: {"from_atom_index": 16, "to_atom_index": 20, "bond_type": 2},
                    36: {"from_atom_index": 17, "to_atom_index": 33, "bond_type": 1},
                    37: {"from_atom_index": 18, "to_atom_index": 34, "bond_type": 1},
                    38: {"from_atom_index": 18, "to_atom_index": 35, "bond_type": 1},
                    39: {"from_atom_index": 18, "to_atom_index": 36, "bond_type": 1},
                    40: {"from_atom_index": 19, "to_atom_index": 21, "bond_type": 2},
                    41: {"from_atom_index": 19, "to_atom_index": 37, "bond_type": 1},
                    42: {"from_atom_index": 20, "to_atom_index": 21, "bond_type": 1},
                    43: {"from_atom_index": 21, "to_atom_index": 38, "bond_type": 1},
                },
            )
        ]

    @pytest.fixture
    def heme_2d_molecule_data(self):
        return [
            (
                {
                    1: {"element": "Fe", "coords": np.array([6.7437, 0.7222, 0.0])},
                    2: {"element": "O", "coords": np.array([7.6407, -5.2892, 0.0])},
                    3: {"element": "O", "coords": np.array([13.2337, 0.2017, 0.0])},
                    4: {"element": "O", "coords": np.array([9.0357, -4.2626, 0.0])},
                    5: {"element": "O", "coords": np.array([12.191, -1.1813, 0.0])},
                    6: {"element": "N", "coords": np.array([6.7568, -0.2777, 0.0])},
                    7: {"element": "N", "coords": np.array([8.2586, 1.0918, 0.0])},
                    8: {"element": "N", "coords": np.array([5.2534, 1.0918, 0.0])},
                    9: {"element": "N", "coords": np.array([6.7233, 2.4613, 0.0])},
                    10: {"element": "C", "coords": np.array([7.2574, -1.8464, 0.0])},
                    11: {"element": "C", "coords": np.array([9.7955, 0.6247, 0.0])},
                    12: {"element": "C", "coords": np.array([7.5588, -0.8787, 0.0])},
                    13: {"element": "C", "coords": np.array([8.8596, 0.3568, 0.0])},
                    14: {"element": "C", "coords": np.array([6.2562, -1.8464, 0.0])},
                    15: {"element": "C", "coords": np.array([9.7955, 1.6259, 0.0])},
                    16: {"element": "C", "coords": np.array([7.8502, -2.6518, 0.0])},
                    17: {"element": "C", "coords": np.array([10.594, 0.0227, 0.0])},
                    18: {"element": "C", "coords": np.array([5.9549, -0.9122, 0.0])},
                    19: {"element": "C", "coords": np.array([8.8261, 1.8938, 0.0])},
                    20: {"element": "C", "coords": np.array([8.5599, -0.6109, 0.0])},
                    21: {"element": "C", "coords": np.array([4.9872, -0.6109, 0.0])},
                    22: {"element": "C", "coords": np.array([8.5265, 2.828, 0.0])},
                    23: {"element": "C", "coords": np.array([7.4491, -3.5678, 0.0])},
                    24: {"element": "C", "coords": np.array([11.5146, 0.4132, 0.0])},
                    25: {"element": "C", "coords": np.array([4.6858, 0.3233, 0.0])},
                    26: {"element": "C", "coords": np.array([7.5588, 3.1293, 0.0])},
                    27: {"element": "C", "coords": np.array([5.5855, -2.5881, 0.0])},
                    28: {"element": "C", "coords": np.array([10.5912, 2.2315, 0.0])},
                    29: {"element": "C", "coords": np.array([3.7182, 0.5912, 0.0])},
                    30: {"element": "C", "coords": np.array([7.2239, 4.0635, 0.0])},
                    31: {"element": "C", "coords": np.array([5.9214, 3.0958, 0.0])},
                    32: {"element": "C", "coords": np.array([6.2228, 4.0635, 0.0])},
                    33: {"element": "C", "coords": np.array([4.6858, 1.8603, 0.0])},
                    34: {"element": "C", "coords": np.array([3.7182, 1.5924, 0.0])},
                    35: {"element": "C", "coords": np.array([4.9537, 2.828, 0.0])},
                    36: {"element": "C", "coords": np.array([2.8521, 0.0912, 0.0])},
                    37: {"element": "C", "coords": np.array([5.63, 4.8689, 0.0])},
                    38: {"element": "C", "coords": np.array([8.0418, -4.3732, 0.0])},
                    39: {"element": "C", "coords": np.array([12.3131, -0.1888, 0.0])},
                    40: {"element": "C", "coords": np.array([7.7995, 4.8812, 0.0])},
                    41: {"element": "C", "coords": np.array([2.9223, 2.1979, 0.0])},
                    42: {"element": "C", "coords": np.array([7.3791, 5.7886, 0.0])},
                    43: {"element": "C", "coords": np.array([2.0, 1.8114, 0.0])},
                    44: {"element": "H", "coords": np.array([8.3663, -2.9953, 0.0])},
                    45: {"element": "H", "coords": np.array([8.2781, -2.2032, 0.0])},
                    46: {"element": "H", "coords": np.array([10.1405, -0.4, 0.0])},
                    47: {"element": "H", "coords": np.array([10.9316, -0.4974, 0.0])},
                    48: {"element": "H", "coords": np.array([8.9897, -1.0577, 0.0])},
                    49: {"element": "H", "coords": np.array([4.551, -1.0515, 0.0])},
                    50: {"element": "H", "coords": np.array([8.963, 3.2682, 0.0])},
                    51: {"element": "H", "coords": np.array([6.9329, -3.2243, 0.0])},
                    52: {"element": "H", "coords": np.array([7.0211, -4.0165, 0.0])},
                    53: {"element": "H", "coords": np.array([11.9681, 0.8359, 0.0])},
                    54: {"element": "H", "coords": np.array([11.177, 0.9333, 0.0])},
                    55: {"element": "H", "coords": np.array([5.1257, -2.1723, 0.0])},
                    56: {"element": "H", "coords": np.array([5.1697, -3.048, 0.0])},
                    57: {"element": "H", "coords": np.array([6.0454, -3.004, 0.0])},
                    58: {"element": "H", "coords": np.array([10.9667, 1.7382, 0.0])},
                    59: {"element": "H", "coords": np.array([11.0846, 2.607, 0.0])},
                    60: {"element": "H", "coords": np.array([10.2157, 2.7249, 0.0])},
                    61: {"element": "H", "coords": np.array([4.5153, 3.2664, 0.0])},
                    62: {"element": "H", "coords": np.array([2.5421, 0.6281, 0.0])},
                    63: {"element": "H", "coords": np.array([2.3152, -0.2188, 0.0])},
                    64: {"element": "H", "coords": np.array([3.1622, -0.4457, 0.0])},
                    65: {"element": "H", "coords": np.array([6.1293, 5.2364, 0.0])},
                    66: {"element": "H", "coords": np.array([5.2625, 5.3682, 0.0])},
                    67: {"element": "H", "coords": np.array([5.1307, 4.5014, 0.0])},
                    68: {"element": "H", "coords": np.array([8.417, 4.8257, 0.0])},
                    69: {"element": "H", "coords": np.array([3.0007, 2.8129, 0.0])},
                    70: {"element": "H", "coords": np.array([7.736, 6.2956, 0.0])},
                    71: {"element": "H", "coords": np.array([6.7616, 5.8441, 0.0])},
                    72: {"element": "H", "coords": np.array([1.5066, 2.1868, 0.0])},
                    73: {"element": "H", "coords": np.array([1.9216, 1.1963, 0.0])},
                    74: {"element": "H", "coords": np.array([8.0082, -5.7886, 0.0])},
                    75: {"element": "H", "coords": np.array([13.7288, -0.1715, 0.0])},
                },
                {
                    0: {"from_atom_index": 2, "to_atom_index": 38, "bond_type": 1},
                    1: {"from_atom_index": 2, "to_atom_index": 74, "bond_type": 1},
                    2: {"from_atom_index": 3, "to_atom_index": 39, "bond_type": 1},
                    3: {"from_atom_index": 3, "to_atom_index": 75, "bond_type": 1},
                    4: {"from_atom_index": 4, "to_atom_index": 38, "bond_type": 2},
                    5: {"from_atom_index": 5, "to_atom_index": 39, "bond_type": 2},
                    6: {"from_atom_index": 6, "to_atom_index": 12, "bond_type": 1},
                    7: {"from_atom_index": 6, "to_atom_index": 18, "bond_type": 1},
                    8: {"from_atom_index": 7, "to_atom_index": 13, "bond_type": 1},
                    9: {"from_atom_index": 7, "to_atom_index": 19, "bond_type": 1},
                    10: {"from_atom_index": 8, "to_atom_index": 25, "bond_type": 2},
                    11: {"from_atom_index": 8, "to_atom_index": 33, "bond_type": 1},
                    12: {"from_atom_index": 9, "to_atom_index": 26, "bond_type": 1},
                    13: {"from_atom_index": 9, "to_atom_index": 31, "bond_type": 2},
                    14: {"from_atom_index": 10, "to_atom_index": 12, "bond_type": 1},
                    15: {"from_atom_index": 10, "to_atom_index": 14, "bond_type": 2},
                    16: {"from_atom_index": 10, "to_atom_index": 16, "bond_type": 1},
                    17: {"from_atom_index": 11, "to_atom_index": 13, "bond_type": 2},
                    18: {"from_atom_index": 11, "to_atom_index": 15, "bond_type": 1},
                    19: {"from_atom_index": 11, "to_atom_index": 17, "bond_type": 1},
                    20: {"from_atom_index": 12, "to_atom_index": 20, "bond_type": 2},
                    21: {"from_atom_index": 13, "to_atom_index": 20, "bond_type": 1},
                    22: {"from_atom_index": 14, "to_atom_index": 18, "bond_type": 1},
                    23: {"from_atom_index": 14, "to_atom_index": 27, "bond_type": 1},
                    24: {"from_atom_index": 15, "to_atom_index": 19, "bond_type": 2},
                    25: {"from_atom_index": 15, "to_atom_index": 28, "bond_type": 1},
                    26: {"from_atom_index": 16, "to_atom_index": 23, "bond_type": 1},
                    27: {"from_atom_index": 16, "to_atom_index": 44, "bond_type": 1},
                    28: {"from_atom_index": 16, "to_atom_index": 45, "bond_type": 1},
                    29: {"from_atom_index": 17, "to_atom_index": 24, "bond_type": 1},
                    30: {"from_atom_index": 17, "to_atom_index": 46, "bond_type": 1},
                    31: {"from_atom_index": 17, "to_atom_index": 47, "bond_type": 1},
                    32: {"from_atom_index": 18, "to_atom_index": 21, "bond_type": 2},
                    33: {"from_atom_index": 19, "to_atom_index": 22, "bond_type": 1},
                    34: {"from_atom_index": 20, "to_atom_index": 48, "bond_type": 1},
                    35: {"from_atom_index": 21, "to_atom_index": 25, "bond_type": 1},
                    36: {"from_atom_index": 21, "to_atom_index": 49, "bond_type": 1},
                    37: {"from_atom_index": 22, "to_atom_index": 26, "bond_type": 2},
                    38: {"from_atom_index": 22, "to_atom_index": 50, "bond_type": 1},
                    39: {"from_atom_index": 23, "to_atom_index": 38, "bond_type": 1},
                    40: {"from_atom_index": 23, "to_atom_index": 51, "bond_type": 1},
                    41: {"from_atom_index": 23, "to_atom_index": 52, "bond_type": 1},
                    42: {"from_atom_index": 24, "to_atom_index": 39, "bond_type": 1},
                    43: {"from_atom_index": 24, "to_atom_index": 53, "bond_type": 1},
                    44: {"from_atom_index": 24, "to_atom_index": 54, "bond_type": 1},
                    45: {"from_atom_index": 25, "to_atom_index": 29, "bond_type": 1},
                    46: {"from_atom_index": 26, "to_atom_index": 30, "bond_type": 1},
                    47: {"from_atom_index": 27, "to_atom_index": 55, "bond_type": 1},
                    48: {"from_atom_index": 27, "to_atom_index": 56, "bond_type": 1},
                    49: {"from_atom_index": 27, "to_atom_index": 57, "bond_type": 1},
                    50: {"from_atom_index": 28, "to_atom_index": 58, "bond_type": 1},
                    51: {"from_atom_index": 28, "to_atom_index": 59, "bond_type": 1},
                    52: {"from_atom_index": 28, "to_atom_index": 60, "bond_type": 1},
                    53: {"from_atom_index": 29, "to_atom_index": 34, "bond_type": 2},
                    54: {"from_atom_index": 29, "to_atom_index": 36, "bond_type": 1},
                    55: {"from_atom_index": 30, "to_atom_index": 32, "bond_type": 2},
                    56: {"from_atom_index": 30, "to_atom_index": 40, "bond_type": 1},
                    57: {"from_atom_index": 31, "to_atom_index": 32, "bond_type": 1},
                    58: {"from_atom_index": 31, "to_atom_index": 35, "bond_type": 1},
                    59: {"from_atom_index": 32, "to_atom_index": 37, "bond_type": 1},
                    60: {"from_atom_index": 33, "to_atom_index": 34, "bond_type": 1},
                    61: {"from_atom_index": 33, "to_atom_index": 35, "bond_type": 2},
                    62: {"from_atom_index": 34, "to_atom_index": 41, "bond_type": 1},
                    63: {"from_atom_index": 35, "to_atom_index": 61, "bond_type": 1},
                    64: {"from_atom_index": 36, "to_atom_index": 62, "bond_type": 1},
                    65: {"from_atom_index": 36, "to_atom_index": 63, "bond_type": 1},
                    66: {"from_atom_index": 36, "to_atom_index": 64, "bond_type": 1},
                    67: {"from_atom_index": 37, "to_atom_index": 65, "bond_type": 1},
                    68: {"from_atom_index": 37, "to_atom_index": 66, "bond_type": 1},
                    69: {"from_atom_index": 37, "to_atom_index": 67, "bond_type": 1},
                    70: {"from_atom_index": 40, "to_atom_index": 42, "bond_type": 2},
                    71: {"from_atom_index": 40, "to_atom_index": 68, "bond_type": 1},
                    72: {"from_atom_index": 41, "to_atom_index": 43, "bond_type": 2},
                    73: {"from_atom_index": 41, "to_atom_index": 69, "bond_type": 1},
                    74: {"from_atom_index": 42, "to_atom_index": 70, "bond_type": 1},
                    75: {"from_atom_index": 42, "to_atom_index": 71, "bond_type": 1},
                    76: {"from_atom_index": 43, "to_atom_index": 72, "bond_type": 1},
                    77: {"from_atom_index": 43, "to_atom_index": 73, "bond_type": 1},
                },
            )
        ]

    @pytest.fixture
    def heme_3d_molecule_data(self):
        return [
            (
                {
                    1: {"element": "O", "coords": np.array([7.1385, 2.705, -0.6711])},
                    2: {"element": "O", "coords": np.array([5.7615, -3.2503, -2.9408])},
                    3: {"element": "O", "coords": np.array([6.7154, 2.1599, 1.493])},
                    4: {"element": "O", "coords": np.array([6.1372, -3.4886, -0.7132])},
                    5: {"element": "N", "coords": np.array([-2.525, 1.9272, 0.2862])},
                    6: {"element": "N", "coords": np.array([-2.6939, -1.118, 0.2758])},
                    7: {"element": "N", "coords": np.array([0.4051, 1.517, 0.2379])},
                    8: {"element": "N", "coords": np.array([0.1811, -1.3404, 0.4974])},
                    9: {"element": "C", "coords": np.array([2.507, 2.3377, 0.8711])},
                    10: {"element": "C", "coords": np.array([2.0591, -2.6167, 0.1996])},
                    11: {"element": "C", "coords": np.array([1.6482, 1.2058, 0.4657])},
                    12: {"element": "C", "coords": np.array([1.6304, 3.3517, 0.8618])},
                    13: {"element": "C", "coords": np.array([1.5429, -1.2639, 0.3342])},
                    14: {"element": "C", "coords": np.array([1.0549, -3.502, 0.2769])},
                    15: {"element": "C", "coords": np.array([0.3143, 2.872, 0.4652])},
                    16: {
                        "element": "C",
                        "coords": np.array([-0.1068, -2.6087, 0.4631]),
                    },
                    17: {"element": "C", "coords": np.array([-2.0505, 3.1577, -0.111])},
                    18: {
                        "element": "C",
                        "coords": np.array([-3.9963, -0.6924, 0.2747]),
                    },
                    19: {"element": "C", "coords": np.array([-2.5688, -2.4592, 0.54])},
                    20: {
                        "element": "C",
                        "coords": np.array([-3.7828, 1.7074, -0.2302]),
                    },
                    21: {"element": "C", "coords": np.array([3.9475, 2.2748, 1.2062])},
                    22: {"element": "C", "coords": np.array([3.5095, -2.9072, 0.0057])},
                    23: {"element": "C", "coords": np.array([2.2658, -0.1348, 0.3202])},
                    24: {"element": "C", "coords": np.array([-3.0486, 3.753, -0.8571])},
                    25: {
                        "element": "C",
                        "coords": np.array([-4.7892, -1.9053, 0.5602]),
                    },
                    26: {
                        "element": "C",
                        "coords": np.array([-4.1304, 2.8451, -0.9341]),
                    },
                    27: {
                        "element": "C",
                        "coords": np.array([-3.9471, -2.9601, 0.7181]),
                    },
                    28: {"element": "C", "coords": np.array([-0.7823, 3.6329, 0.3107])},
                    29: {
                        "element": "C",
                        "coords": np.array([-1.4551, -3.2035, 0.6248]),
                    },
                    30: {"element": "C", "coords": np.array([-4.5176, 0.5263, 0.0526])},
                    31: {"element": "C", "coords": np.array([1.9005, 4.7807, 1.1965])},
                    32: {
                        "element": "C",
                        "coords": np.array([4.8520e00, 2.5394e00, 3.3000e-03]),
                    },
                    33: {
                        "element": "C",
                        "coords": np.array([3.9112, -2.9257, -1.4638]),
                    },
                    34: {"element": "C", "coords": np.array([1.0259, -4.9791, 0.1919])},
                    35: {
                        "element": "C",
                        "coords": np.array([-2.9926, 5.1012, -1.4661]),
                    },
                    36: {
                        "element": "C",
                        "coords": np.array([-6.2814, -1.8735, 0.6439]),
                    },
                    37: {"element": "C", "coords": np.array([-5.36, 3.0491, -1.6044])},
                    38: {
                        "element": "C",
                        "coords": np.array([-4.3596, -4.3097, 1.0073]),
                    },
                    39: {"element": "C", "coords": np.array([6.3128, 2.4348, 0.3698])},
                    40: {
                        "element": "C",
                        "coords": np.array([5.3729, -3.2588, -1.6419]),
                    },
                    41: {
                        "element": "C",
                        "coords": np.array([-6.1715, 2.1311, -2.1847]),
                    },
                    42: {
                        "element": "C",
                        "coords": np.array([-4.6339, -5.2115, 0.0645]),
                    },
                    43: {"element": "H", "coords": np.array([4.1938, 1.3129, 1.6711])},
                    44: {"element": "H", "coords": np.array([4.1687, 3.0159, 1.9856])},
                    45: {"element": "H", "coords": np.array([3.7406, -3.8863, 0.4471])},
                    46: {"element": "H", "coords": np.array([4.1341, -2.2066, 0.5729])},
                    47: {"element": "H", "coords": np.array([3.3403, -0.1671, 0.1855])},
                    48: {"element": "H", "coords": np.array([-0.7083, 4.7057, 0.4708])},
                    49: {
                        "element": "H",
                        "coords": np.array([-1.5138, -4.2667, 0.8304]),
                    },
                    50: {"element": "H", "coords": np.array([-2.0287, 1.2921, 0.8961])},
                    51: {
                        "element": "H",
                        "coords": np.array([-1.9035, -0.5315, 0.0596]),
                    },
                    52: {"element": "H", "coords": np.array([-5.5979, 0.6383, 0.092])},
                    53: {"element": "H", "coords": np.array([1.2897, 5.1008, 2.0471])},
                    54: {"element": "H", "coords": np.array([2.9482, 4.9486, 1.4639])},
                    55: {"element": "H", "coords": np.array([1.6775, 5.4274, 0.3414])},
                    56: {"element": "H", "coords": np.array([4.6712, 3.5474, -0.3875])},
                    57: {"element": "H", "coords": np.array([4.6518, 1.8113, -0.7907])},
                    58: {
                        "element": "H",
                        "coords": np.array([3.3272, -3.6772, -2.0076]),
                    },
                    59: {
                        "element": "H",
                        "coords": np.array([3.7327, -1.9441, -1.9173]),
                    },
                    60: {"element": "H", "coords": np.array([2.0137, -5.3942, -0.029])},
                    61: {
                        "element": "H",
                        "coords": np.array([0.3499, -5.3061, -0.6044]),
                    },
                    62: {"element": "H", "coords": np.array([0.6873, -5.4128, 1.1379])},
                    63: {
                        "element": "H",
                        "coords": np.array([-3.5447, 5.8188, -0.8503]),
                    },
                    64: {
                        "element": "H",
                        "coords": np.array([-3.4318, 5.0997, -2.4692]),
                    },
                    65: {"element": "H", "coords": np.array([-1.9644, 5.4627, -1.568])},
                    66: {
                        "element": "H",
                        "coords": np.array([-6.7151, -1.5506, -0.3082]),
                    },
                    67: {"element": "H", "coords": np.array([-6.61, -1.1876, 1.4317])},
                    68: {
                        "element": "H",
                        "coords": np.array([-6.7014, -2.8571, 0.8758]),
                    },
                    69: {"element": "H", "coords": np.array([-5.693, 4.0826, -1.6921])},
                    70: {
                        "element": "H",
                        "coords": np.array([-4.4411, -4.5822, 2.0553]),
                    },
                    71: {
                        "element": "H",
                        "coords": np.array([-7.0854, 2.4544, -2.6733]),
                    },
                    72: {
                        "element": "H",
                        "coords": np.array([-5.9398, 1.0737, -2.2183]),
                    },
                    73: {
                        "element": "H",
                        "coords": np.array([-4.9394, -6.2155, 0.3391]),
                    },
                    74: {
                        "element": "H",
                        "coords": np.array([-4.5621, -4.9765, -0.9923]),
                    },
                    75: {"element": "H", "coords": np.array([8.0834, 2.6451, -0.4143])},
                    76: {"element": "H", "coords": np.array([6.7157, -3.456, -3.0389])},
                },
                {
                    0: {"from_atom_index": 1, "to_atom_index": 39, "bond_type": 1},
                    1: {"from_atom_index": 1, "to_atom_index": 75, "bond_type": 1},
                    2: {"from_atom_index": 2, "to_atom_index": 40, "bond_type": 1},
                    3: {"from_atom_index": 2, "to_atom_index": 76, "bond_type": 1},
                    4: {"from_atom_index": 3, "to_atom_index": 39, "bond_type": 2},
                    5: {"from_atom_index": 4, "to_atom_index": 40, "bond_type": 2},
                    6: {"from_atom_index": 5, "to_atom_index": 17, "bond_type": 1},
                    7: {"from_atom_index": 5, "to_atom_index": 20, "bond_type": 1},
                    8: {"from_atom_index": 5, "to_atom_index": 50, "bond_type": 1},
                    9: {"from_atom_index": 6, "to_atom_index": 18, "bond_type": 1},
                    10: {"from_atom_index": 6, "to_atom_index": 19, "bond_type": 1},
                    11: {"from_atom_index": 6, "to_atom_index": 51, "bond_type": 1},
                    12: {"from_atom_index": 7, "to_atom_index": 11, "bond_type": 2},
                    13: {"from_atom_index": 7, "to_atom_index": 15, "bond_type": 1},
                    14: {"from_atom_index": 8, "to_atom_index": 13, "bond_type": 1},
                    15: {"from_atom_index": 8, "to_atom_index": 16, "bond_type": 2},
                    16: {"from_atom_index": 9, "to_atom_index": 11, "bond_type": 1},
                    17: {"from_atom_index": 9, "to_atom_index": 12, "bond_type": 2},
                    18: {"from_atom_index": 9, "to_atom_index": 21, "bond_type": 1},
                    19: {"from_atom_index": 10, "to_atom_index": 13, "bond_type": 1},
                    20: {"from_atom_index": 10, "to_atom_index": 14, "bond_type": 2},
                    21: {"from_atom_index": 10, "to_atom_index": 22, "bond_type": 1},
                    22: {"from_atom_index": 11, "to_atom_index": 23, "bond_type": 1},
                    23: {"from_atom_index": 12, "to_atom_index": 15, "bond_type": 1},
                    24: {"from_atom_index": 12, "to_atom_index": 31, "bond_type": 1},
                    25: {"from_atom_index": 13, "to_atom_index": 23, "bond_type": 2},
                    26: {"from_atom_index": 14, "to_atom_index": 16, "bond_type": 1},
                    27: {"from_atom_index": 14, "to_atom_index": 34, "bond_type": 1},
                    28: {"from_atom_index": 15, "to_atom_index": 28, "bond_type": 2},
                    29: {"from_atom_index": 16, "to_atom_index": 29, "bond_type": 1},
                    30: {"from_atom_index": 17, "to_atom_index": 24, "bond_type": 2},
                    31: {"from_atom_index": 17, "to_atom_index": 28, "bond_type": 1},
                    32: {"from_atom_index": 18, "to_atom_index": 25, "bond_type": 1},
                    33: {"from_atom_index": 18, "to_atom_index": 30, "bond_type": 2},
                    34: {"from_atom_index": 19, "to_atom_index": 27, "bond_type": 1},
                    35: {"from_atom_index": 19, "to_atom_index": 29, "bond_type": 2},
                    36: {"from_atom_index": 20, "to_atom_index": 26, "bond_type": 2},
                    37: {"from_atom_index": 20, "to_atom_index": 30, "bond_type": 1},
                    38: {"from_atom_index": 21, "to_atom_index": 32, "bond_type": 1},
                    39: {"from_atom_index": 21, "to_atom_index": 43, "bond_type": 1},
                    40: {"from_atom_index": 21, "to_atom_index": 44, "bond_type": 1},
                    41: {"from_atom_index": 22, "to_atom_index": 33, "bond_type": 1},
                    42: {"from_atom_index": 22, "to_atom_index": 45, "bond_type": 1},
                    43: {"from_atom_index": 22, "to_atom_index": 46, "bond_type": 1},
                    44: {"from_atom_index": 23, "to_atom_index": 47, "bond_type": 1},
                    45: {"from_atom_index": 24, "to_atom_index": 26, "bond_type": 1},
                    46: {"from_atom_index": 24, "to_atom_index": 35, "bond_type": 1},
                    47: {"from_atom_index": 25, "to_atom_index": 27, "bond_type": 2},
                    48: {"from_atom_index": 25, "to_atom_index": 36, "bond_type": 1},
                    49: {"from_atom_index": 26, "to_atom_index": 37, "bond_type": 1},
                    50: {"from_atom_index": 27, "to_atom_index": 38, "bond_type": 1},
                    51: {"from_atom_index": 28, "to_atom_index": 48, "bond_type": 1},
                    52: {"from_atom_index": 29, "to_atom_index": 49, "bond_type": 1},
                    53: {"from_atom_index": 30, "to_atom_index": 52, "bond_type": 1},
                    54: {"from_atom_index": 31, "to_atom_index": 53, "bond_type": 1},
                    55: {"from_atom_index": 31, "to_atom_index": 54, "bond_type": 1},
                    56: {"from_atom_index": 31, "to_atom_index": 55, "bond_type": 1},
                    57: {"from_atom_index": 32, "to_atom_index": 39, "bond_type": 1},
                    58: {"from_atom_index": 32, "to_atom_index": 56, "bond_type": 1},
                    59: {"from_atom_index": 32, "to_atom_index": 57, "bond_type": 1},
                    60: {"from_atom_index": 33, "to_atom_index": 40, "bond_type": 1},
                    61: {"from_atom_index": 33, "to_atom_index": 58, "bond_type": 1},
                    62: {"from_atom_index": 33, "to_atom_index": 59, "bond_type": 1},
                    63: {"from_atom_index": 34, "to_atom_index": 60, "bond_type": 1},
                    64: {"from_atom_index": 34, "to_atom_index": 61, "bond_type": 1},
                    65: {"from_atom_index": 34, "to_atom_index": 62, "bond_type": 1},
                    66: {"from_atom_index": 35, "to_atom_index": 63, "bond_type": 1},
                    67: {"from_atom_index": 35, "to_atom_index": 64, "bond_type": 1},
                    68: {"from_atom_index": 35, "to_atom_index": 65, "bond_type": 1},
                    69: {"from_atom_index": 36, "to_atom_index": 66, "bond_type": 1},
                    70: {"from_atom_index": 36, "to_atom_index": 67, "bond_type": 1},
                    71: {"from_atom_index": 36, "to_atom_index": 68, "bond_type": 1},
                    72: {"from_atom_index": 37, "to_atom_index": 41, "bond_type": 2},
                    73: {"from_atom_index": 37, "to_atom_index": 69, "bond_type": 1},
                    74: {"from_atom_index": 38, "to_atom_index": 42, "bond_type": 2},
                    75: {"from_atom_index": 38, "to_atom_index": 70, "bond_type": 1},
                    76: {"from_atom_index": 41, "to_atom_index": 71, "bond_type": 1},
                    77: {"from_atom_index": 41, "to_atom_index": 72, "bond_type": 1},
                    78: {"from_atom_index": 42, "to_atom_index": 73, "bond_type": 1},
                    79: {"from_atom_index": 42, "to_atom_index": 74, "bond_type": 1},
                },
            )
        ]
